@@ -86,12 +86,13 @@ public class Job {
             Source source = (Source) Class.forName(jobConf.get(JobConstants.JOB_SOURCE)).newInstance();
             for (Reader reader : source.split(jobConf)) {
                 Sink writer = (Sink) Class.forName(jobConf.get(JobConstants.JOB_SINK)).newInstance();
-                writer.setSourceFile(reader.getReadFile());
+                writer.setSourceName(reader.getReadSource());
                 Channel channel = (Channel) Class.forName(jobConf.get(JobConstants.JOB_CHANNEL)).newInstance();
                 String taskId = String.format("%s_%d", jobInstanceId, index++);
                 taskList.add(new Task(taskId, reader, writer, channel, getJobConf()));
             }
         } catch (Exception ex) {
+            LOGGER.error("create taks fail", ex);
             throw new RuntimeException(ex);
         }
         return taskList;
