@@ -23,7 +23,10 @@ import org.apache.inlong.agent.conf.JobProfile;
 import org.apache.inlong.agent.constants.AgentConstants;
 import org.apache.inlong.agent.plugin.Channel;
 import org.apache.inlong.agent.plugin.Message;
+import org.apache.inlong.agent.plugin.metrics.PluginJmxMetric;
 import org.apache.inlong.agent.plugin.metrics.PluginMetric;
+import org.apache.inlong.agent.plugin.metrics.PluginPrometheusMetric;
+import org.apache.inlong.agent.utils.ConfigUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -31,9 +34,19 @@ public class MemoryChannel implements Channel {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(MemoryChannel.class);
 
+    private static final String MEMORY_CHANNEL_TAG_NAME = "AgentMemoryPlugin";
+
     private LinkedBlockingQueue<Message> queue;
 
-    private final PluginMetric metric = new PluginMetric();
+    private final PluginMetric pluginMetricNew;
+
+    public MemoryChannel() {
+        if (ConfigUtil.isPrometheusEnabled()) {
+            this.pluginMetricNew = new PluginPrometheusMetric(MEMORY_CHANNEL_TAG_NAME);
+        } else {
+            this.pluginMetricNew = new PluginJmxMetric(MEMORY_CHANNEL_TAG_NAME);
+        }
+    }
 
     /**
      * {@inheritDoc}
@@ -42,12 +55,12 @@ public class MemoryChannel implements Channel {
     public void push(Message message) {
         try {
             if (message != null) {
-                metric.readNum.incr();
+                pluginMetricNew.incReadNum();
                 queue.put(message);
-                metric.readSuccessNum.incr();
+                pluginMetricNew.incReadSuccessNum();
             }
         } catch (InterruptedException ex) {
-            metric.readFailedNum.incr();
+            pluginMetricNew.incReadFailedNum();
             Thread.currentThread().interrupt();
         }
     }
@@ -56,17 +69,17 @@ public class MemoryChannel implements Channel {
     public boolean push(Message message, long timeout, TimeUnit unit) {
         try {
             if (message != null) {
-                metric.readNum.incr();
+                pluginMetricNew.incReadNum();
                 boolean result = queue.offer(message, timeout, unit);
                 if (result) {
-                    metric.readSuccessNum.incr();
+                    pluginMetricNew.incReadSuccessNum();
                 } else {
-                    metric.readFailedNum.incr();
+                    pluginMetricNew.incReadFailedNum();
                 }
                 return result;
             }
         } catch (InterruptedException ex) {
-            metric.readFailedNum.incr();
+            pluginMetricNew.incReadFailedNum();
             Thread.currentThread().interrupt();
         }
         return false;
@@ -80,11 +93,11 @@ public class MemoryChannel implements Channel {
         try {
             Message message = queue.poll(timeout, unit);
             if (message != null) {
-                metric.sendSuccessNum.incr();
+                pluginMetricNew.incSendSuccessNum();
             }
             return message;
         } catch (InterruptedException ex) {
-            metric.sendFailedNum.incr();
+            pluginMetricNew.incSendFailedNum();
             Thread.currentThread().interrupt();
             throw new IllegalStateException(ex);
         }
@@ -104,7 +117,8 @@ public class MemoryChannel implements Channel {
         }
         LOGGER.info("destroy channel, memory channel metric, readNum: {}, readSuccessNum: {}, "
             + "readFailedNum: {}, sendSuccessNum: {}, sendFailedNum: {}",
-            metric.readNum.snapshot(), metric.readSuccessNum.snapshot(), metric.readFailedNum.snapshot(),
-            metric.sendSuccessNum.snapshot(), metric.sendFailedNum.snapshot());
+            pluginMetricNew.getReadNum(), pluginMetricNew.getReadSuccessNum(),
+            pluginMetricNew.getReadFailedNum(), pluginMetricNew.getSendSuccessNum(),
+            pluginMetricNew.getSendFailedNum());
     }
 }
