@@ -30,8 +30,12 @@ import java.util.List;
 import org.apache.inlong.agent.conf.JobProfile;
 import org.apache.inlong.agent.plugin.Reader;
 import org.apache.inlong.agent.plugin.Source;
+import org.apache.inlong.agent.plugin.metrics.SourceJmxMetric;
+import org.apache.inlong.agent.plugin.metrics.SourceMetrics;
+import org.apache.inlong.agent.plugin.metrics.SourcePrometheusMetrics;
 import org.apache.inlong.agent.plugin.sources.reader.TextFileReader;
 import org.apache.inlong.agent.plugin.utils.PluginUtils;
+import org.apache.inlong.agent.utils.ConfigUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -42,9 +46,21 @@ public class TextFileSource implements Source {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(TextFileSource.class);
 
+    private static final String TEXT_FILE_SOURCE_TAG_NAME = "AgentTextFileSourceMetric";
+
     // path + suffix
     public static final String MD5_SUFFIX = ".md5";
 
+    private final SourceMetrics sourceMetrics;
+
+    public TextFileSource() {
+        if (ConfigUtil.isPrometheusEnabled()) {
+            this.sourceMetrics = new SourcePrometheusMetrics(TEXT_FILE_SOURCE_TAG_NAME);
+        } else {
+            this.sourceMetrics = new SourceJmxMetric(TEXT_FILE_SOURCE_TAG_NAME);
+        }
+    }
+
     @Override
     public List<Reader> split(JobProfile jobConf) {
         Collection<File> allFiles = PluginUtils.findSuitFiles(jobConf);
@@ -60,6 +76,8 @@ public class TextFileSource implements Source {
             addValidator(filterPattern, textFileReader);
             result.add(textFileReader);
         }
+        // increment the count of successful sources
+        sourceMetrics.incSourceSuccessCount();
         return result;
     }
 
