@@ -17,11 +17,6 @@
 
 package org.apache.inlong.dataproxy.sink;
 
-import com.google.common.base.Preconditions;
-import com.google.common.cache.CacheBuilder;
-import com.google.common.cache.CacheLoader;
-import com.google.common.cache.LoadingCache;
-
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -44,10 +39,15 @@ import org.apache.flume.Transaction;
 import org.apache.flume.conf.Configurable;
 import org.apache.flume.sink.AbstractSink;
 import org.apache.flume.source.shaded.guava.RateLimiter;
+import org.apache.inlong.commons.config.metrics.MetricRegister;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.config.holder.ConfigUpdateCallback;
 import org.apache.inlong.dataproxy.consts.AttributeConstants;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
+import org.apache.inlong.dataproxy.metrics.DataProxyMetricItem;
+import org.apache.inlong.dataproxy.metrics.DataProxyMetricItemSet;
+import org.apache.inlong.dataproxy.metrics.audit.AuditUtils;
+import org.apache.inlong.dataproxy.utils.Constants;
 import org.apache.inlong.dataproxy.utils.NetworkUtils;
 import org.apache.inlong.tubemq.client.config.TubeClientConfig;
 import org.apache.inlong.tubemq.client.exception.TubeClientException;
@@ -58,14 +58,21 @@ import org.apache.inlong.tubemq.client.producer.MessageSentResult;
 import org.apache.inlong.tubemq.corebase.Message;
 import org.apache.inlong.tubemq.corebase.TErrCodeConstants;
 import org.apache.inlong.tubemq.corerpc.exception.OverflowException;
+import org.apache.pulsar.shade.org.apache.commons.lang.math.NumberUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.base.Preconditions;
+import com.google.common.cache.CacheBuilder;
+import com.google.common.cache.CacheLoader;
+import com.google.common.cache.LoadingCache;
+
 public class MetaSink extends AbstractSink implements Configurable {
 
     private static final Logger logger = LoggerFactory.getLogger(MetaSink.class);
     private static int MAX_TOPICS_EACH_PRODUCER_HOLD = 200;
     private static final String TUBE_REQUEST_TIMEOUT = "tube-request-timeout";
+    private static final String KEY_DISK_IO_RATE_PER_SEC = "disk-io-rate-per-sec";
 
     private static int BAD_EVENT_QUEUE_SIZE = 10000;
 
@@ -89,8 +96,8 @@ public class MetaSink extends AbstractSink implements Configurable {
     private static String MAX_TOPICS_EACH_PRODUCER_HOLD_NAME = "max-topic-each-producer-hold";
 
     private static final String LOG_TOPIC = "proxy-log-topic";
-    private static final String TID = "proxy-log-tid";
-    private static final String BID = "proxy-log-bid";
+    private static final String STREAMID = "proxy-log-streamid";
+    private static final String GROUPID = "proxy-log-groupid";
     private static final String SEND_REMOTE = "send-remote";
     private static final String topicsFilePath = "topics.properties";
     private static final String slaTopicFilePath = "slaTopics.properties";
@@ -104,8 +111,8 @@ public class MetaSink extends AbstractSink implements Configurable {
     private int maxSurvivedSize = 100000;
 
     private String proxyLogTopic = "teg_manager";
-    private String proxyLogBid = "b_teg_manager";
-    private String proxyLogTid = "proxy_measure_log";
+    private String proxyLogGroupId = "b_teg_manager";
+    private String proxyLogStreamId = "proxy_measure_log";
     private boolean sendRemote = false;
     private ConfigManager configManager;
     private Map<String, String> topicProperties;
@@ -135,6 +142,9 @@ public class MetaSink extends AbstractSink implements Configurable {
     private long sessionMaxAllowedDelayedMsgCount;
     private long nettyWriteBufferHighWaterMark;
     private int recoverthreadcount;
+    //
+    private Map<String, String> dimensions;
+    private DataProxyMetricItemSet metricItemSet;
 
     private static final LoadingCache<String, Long> agentIdCache = CacheBuilder
             .newBuilder().concurrencyLevel(4 * 8).initialCapacity(5000000).expireAfterAccess(30, TimeUnit.SECONDS)
@@ -321,6 +331,14 @@ public class MetaSink extends AbstractSink implements Configurable {
 
     @Override
     public void start() {
+        this.dimensions = new HashMap<>();
+        this.dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, "DataProxy");
+        this.dimensions.put(DataProxyMetricItem.KEY_SINK_ID, this.getName());
+        //register metrics
+        this.metricItemSet = new DataProxyMetricItemSet(this.getName());
+        MetricRegister.register(metricItemSet);
+        
+        //create tube connection
         try {
             createConnection();
         } catch (FlumeException e) {
@@ -371,13 +389,13 @@ public class MetaSink extends AbstractSink implements Configurable {
                 } else {
                     Message message = new Message(topic, event.getBody());
                     message.setAttrKeyVal("dataproxyip", NetworkUtils.getLocalIp());
-                    String tid = "";
+                    String streamId = "";
                     if (event.getHeaders().containsKey(AttributeConstants.INTERFACE_ID)) {
-                        tid = event.getHeaders().get(AttributeConstants.INTERFACE_ID);
+                        streamId = event.getHeaders().get(AttributeConstants.INTERFACE_ID);
                     } else if (event.getHeaders().containsKey(AttributeConstants.INAME)) {
-                        tid = event.getHeaders().get(AttributeConstants.INAME);
+                        streamId = event.getHeaders().get(AttributeConstants.INAME);
                     }
-                    message.putSystemHeader(tid, event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
+                    message.putSystemHeader(streamId, event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
 
                     producer.sendMessage(message, new MyCallback(es));
                     flag.set(true);
@@ -399,13 +417,13 @@ public class MetaSink extends AbstractSink implements Configurable {
 
                     Message message = new Message(topic, event.getBody());
                     message.setAttrKeyVal("dataproxyip", NetworkUtils.getLocalIp());
-                    String tid = "";
+                    String streamId = "";
                     if (event.getHeaders().containsKey(AttributeConstants.INTERFACE_ID)) {
-                        tid = event.getHeaders().get(AttributeConstants.INTERFACE_ID);
+                        streamId = event.getHeaders().get(AttributeConstants.INTERFACE_ID);
                     } else if (event.getHeaders().containsKey(AttributeConstants.INAME)) {
-                        tid = event.getHeaders().get(AttributeConstants.INAME);
+                        streamId = event.getHeaders().get(AttributeConstants.INAME);
                     }
-                    message.putSystemHeader(tid, event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
+                    message.putSystemHeader(streamId, event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
 
                     producer.sendMessage(message, new MyCallback(es));
                     flag.set(true);
@@ -521,16 +539,20 @@ public class MetaSink extends AbstractSink implements Configurable {
 
     public class MyCallback implements MessageSentCallback {
         private EventStat myEventStat;
+        private long sendTime;
 
         public MyCallback(EventStat eventStat) {
             this.myEventStat = eventStat;
+            this.sendTime = System.currentTimeMillis();
         }
 
         @Override
         public void onMessageSent(final MessageSentResult result) {
             if (result.isSuccess()) {
                 // TODO: add stats
+                this.addMetric(myEventStat.getEvent(), true, sendTime);
             } else {
+                this.addMetric(myEventStat.getEvent(), false, 0);
                 if (result.getErrCode() == TErrCodeConstants.FORBIDDEN) {
                     logger.warn("Send message failed, error message: {}, resendQueue size: {}, event:{}",
                             result.getErrMsg(), resendQueue.size(),
@@ -547,6 +569,42 @@ public class MetaSink extends AbstractSink implements Configurable {
             }
         }
 
+        /**
+         * addMetric
+         * 
+         * @param event
+         * @param result
+         * @param sendTime
+         */
+        private void addMetric(Event event, boolean result, long sendTime) {
+            Map<String, String> dimensions = new HashMap<>();
+            dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, MetaSink.this.getName());
+            dimensions.put(DataProxyMetricItem.KEY_SINK_ID, MetaSink.this.getName());
+            dimensions.put(DataProxyMetricItem.KEY_SINK_DATA_ID, event.getHeaders().getOrDefault(TOPIC, ""));
+            DataProxyMetricItem.fillInlongId(event, dimensions);
+            DataProxyMetricItem.fillAuditFormatTime(event, dimensions);
+            DataProxyMetricItem metricItem = MetaSink.this.metricItemSet.findMetricItem(dimensions);
+            if (result) {
+                metricItem.sendSuccessCount.incrementAndGet();
+                metricItem.sendSuccessSize.addAndGet(event.getBody().length);
+                AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_SEND_SUCCESS, event);
+                if (sendTime > 0) {
+                    long currentTime = System.currentTimeMillis();
+                    long msgTime = NumberUtils.toLong(event.getHeaders().get(Constants.HEADER_KEY_MSG_TIME),
+                            sendTime);
+                    long sinkDuration = currentTime - sendTime;
+                    long nodeDuration = currentTime - NumberUtils.toLong(Constants.HEADER_KEY_SOURCE_TIME, msgTime);
+                    long wholeDuration = currentTime - msgTime;
+                    metricItem.sinkDuration.addAndGet(sinkDuration);
+                    metricItem.nodeDuration.addAndGet(nodeDuration);
+                    metricItem.wholeDuration.addAndGet(wholeDuration);
+                }
+            } else {
+                metricItem.sendFailCount.incrementAndGet();
+                metricItem.sendFailSize.addAndGet(event.getBody().length);
+            }
+        }
+
         @Override
         public void onException(final Throwable e) {
             Throwable t = e;
@@ -613,6 +671,15 @@ public class MetaSink extends AbstractSink implements Configurable {
                     tx.rollback();
                 } else {
                     tx.commit();
+                    // metric
+                    if (event.getHeaders().containsKey(TOPIC)) {
+                        dimensions.put(DataProxyMetricItem.KEY_SINK_DATA_ID, event.getHeaders().get(TOPIC));
+                    } else {
+                        dimensions.put(DataProxyMetricItem.KEY_SINK_DATA_ID, "");
+                    }
+                    DataProxyMetricItem metricItem = this.metricItemSet.findMetricItem(dimensions);
+                    metricItem.readFailCount.incrementAndGet();
+                    metricItem.readFailSize.addAndGet(event.getBody().length);
                 }
             } else {
 
@@ -700,8 +767,8 @@ public class MetaSink extends AbstractSink implements Configurable {
         }
         if (sendRemote) {
             proxyLogTopic = context.getString(LOG_TOPIC, proxyLogTopic);
-            proxyLogBid = context.getString(BID, proxyLogTid);
-            proxyLogTid = context.getString(TID, proxyLogTid);
+            proxyLogGroupId = context.getString(GROUPID, proxyLogStreamId);
+            proxyLogStreamId = context.getString(STREAMID, proxyLogStreamId);
         }
 
         resendQueue = new LinkedBlockingQueue<>(BAD_EVENT_QUEUE_SIZE);
@@ -712,7 +779,7 @@ public class MetaSink extends AbstractSink implements Configurable {
         sinkThreadPool = new Thread[threadNum];
         eventQueue = new LinkedBlockingQueue<Event>(EVENT_QUEUE_SIZE);
 
-        diskIORatePerSec = context.getLong("disk-io-rate-per-sec", 0L);
+        diskIORatePerSec = context.getLong(KEY_DISK_IO_RATE_PER_SEC, 0L);
         if (diskIORatePerSec != 0) {
             diskRateLimiter = RateLimiter.create(diskIORatePerSec);
         }
@@ -728,4 +795,13 @@ public class MetaSink extends AbstractSink implements Configurable {
         recoverthreadcount = context.getInteger(ConfigConstants.RECOVER_THREAD_COUNT,
                 Runtime.getRuntime().availableProcessors() + 1);
     }
+
+    /**
+     * get metricItemSet
+     * @return the metricItemSet
+     */
+    public DataProxyMetricItemSet getMetricItemSet() {
+        return metricItemSet;
+    }
+    
 }
