@@ -49,9 +49,9 @@ import org.apache.inlong.dataproxy.sink.pulsar.CreatePulsarClientCallBack;
 import org.apache.inlong.dataproxy.sink.pulsar.PulsarClientService;
 import org.apache.inlong.dataproxy.sink.pulsar.SendMessageCallBack;
 import org.apache.inlong.dataproxy.utils.FailoverChannelProcessorHolder;
-import org.apache.inlong.dataproxy.utils.LogCounter;
-import org.apache.inlong.dataproxy.utils.MonitorIndex;
-import org.apache.inlong.dataproxy.utils.MonitorIndexExt;
+import org.apache.inlong.commons.monitor.LogCounter;
+import org.apache.inlong.commons.monitor.MonitorIndex;
+import org.apache.inlong.commons.monitor.MonitorIndexExt;
 import org.apache.inlong.dataproxy.utils.NetworkUtils;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.client.api.PulsarClientException.AlreadyClosedException;
@@ -202,16 +202,20 @@ public class PulsarSink extends AbstractSink implements Configurable,
         /*
          * stat pulsar performance
          */
-        System.out.println("pulsarPerformanceTask!!!!!!");
+        logger.info("PulsarPerformanceTask!!!!!!");
         scheduledExecutorService.scheduleWithFixedDelay(pulsarPerformanceTask, 0L,
                 PRINT_INTERVAL, TimeUnit.SECONDS);
     }
 
     public PulsarSink() {
         super();
-        logger.debug("new instance of PulsarSink!");
+        logger.info("new instance of PulsarSink!");
     }
 
+    /**
+     * configure
+     * @param context
+     */
     public void configure(Context context) {
         logger.info("PulsarSink started and context = {}", context.toString());
         isNewMetricOn = context.getBoolean("new-metric-on", true);
@@ -306,9 +310,9 @@ public class PulsarSink extends AbstractSink implements Configurable,
              * switch for lots of metrics
              */
             if (isNewMetricOn) {
-                monitorIndex = new MonitorIndex("Sink", statIntervalSec, maxMonitorCnt);
+                monitorIndex = new MonitorIndex("Pulsar_Sink", statIntervalSec, maxMonitorCnt);
             }
-            monitorIndexExt = new MonitorIndexExt("TDBus_monitors#" + this.getName(),
+            monitorIndexExt = new MonitorIndexExt("Pulsar_Sink_monitors#" + this.getName(),
                     statIntervalSec, maxMonitorCnt);
         }
 
@@ -319,7 +323,7 @@ public class PulsarSink extends AbstractSink implements Configurable,
         try {
             initTopicSet(new HashSet<String>(topicProperties.values()));
         } catch (Exception e) {
-            logger.info("meta sink start publish topic fail.",e);
+            logger.info("pulsar sink start publish topic fail.",e);
         }
 
         for (int i = 0; i < sinkThreadPool.length; i++) {
@@ -328,7 +332,7 @@ public class PulsarSink extends AbstractSink implements Configurable,
                     + i);
             sinkThreadPool[i].start();
         }
-        logger.debug("meta sink started");
+        logger.debug("pulsar sink started");
     }
 
     @Override
@@ -350,7 +354,7 @@ public class PulsarSink extends AbstractSink implements Configurable,
             try {
                 monitorIndex.shutDown();
             } catch (Exception e) {
-                logger.warn("statrunner interrupted");
+                logger.warn("stat runner interrupted");
             }
         }
         if (sinkThreadPool != null) {
@@ -402,7 +406,7 @@ public class PulsarSink extends AbstractSink implements Configurable,
             try {
                 tx.rollback();
             } catch (Throwable e) {
-                logger.error("metasink transaction rollback exception",e);
+                logger.error("pulsar sink transaction rollback exception",e);
 
             }
         } finally {
@@ -459,14 +463,15 @@ public class PulsarSink extends AbstractSink implements Configurable,
                     }
 
                     /*
-                     * SINK_INTF#metasink1#topic#streamId#clientIp#busIP#pkgTime#successCnt#packcnt
+                     * SINK_INTF#pulsarsink1#topic#streamId#clientIp#busIP#pkgTime#successCnt
+                     * #packcnt
                      * #packsize#failCnt
                      */
                     StringBuilder newbase = new StringBuilder();
                     newbase.append(this.getName()).append(SEPARATOR).append(topic).append(SEPARATOR)
                             .append(streamId).append(SEPARATOR).append(nodeIp)
                             .append(SEPARATOR).append(NetworkUtils.getLocalIp())
-                            .append(SEPARATOR).append(msgId).append(SEPARATOR)
+                            .append(SEPARATOR).append(SEPARATOR)
                             .append(event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
 
                     long messageSize = event.getBody().length;
@@ -501,7 +506,7 @@ public class PulsarSink extends AbstractSink implements Configurable,
     }
 
     @Override
-    public void handleMessageSendSuccess(Object result,  EventStat eventStat) {
+    public void handleMessageSendSuccess(String topic, Object result,  EventStat eventStat) {
         /*
          * Statistics pulsar performance
          */
@@ -518,19 +523,19 @@ public class PulsarSink extends AbstractSink implements Configurable,
         if (nowCnt % logEveryNEvents == 0 && nowCnt != lastSuccessSendCnt.get()) {
             lastSuccessSendCnt.set(nowCnt);
             t2 = System.currentTimeMillis();
-            logger.info("metasink {}, succ put {} events to pulsar,"
+            logger.info("Pulsar sink {}, succ put {} events to pulsar,"
                     + " in the past {} millsec", new Object[] {
                     getName(), (nowCnt - oldCnt), (t2 - t1)
             });
             t1 = t2;
         }
-        monitorIndexExt.incrementAndGet("METASINK_SUCCESS");
+        monitorIndexExt.incrementAndGet("PULSAR_SINK_SUCCESS");
         editStatistic(eventStat.getEvent(), null, result.toString());
     }
 
     @Override
-    public void handleMessageSendException(EventStat eventStat,  Object e) {
-        monitorIndexExt.incrementAndGet("METASINK_EXP");
+    public void handleMessageSendException(String topic, EventStat eventStat,  Object e) {
+        monitorIndexExt.incrementAndGet("PULSAR_SINK_EXP");
         if (e instanceof TooLongFrameException) {
             PulsarSink.this.overflow = true;
         } else if (e instanceof ProducerQueueIsFullError) {
@@ -668,8 +673,9 @@ public class PulsarSink extends AbstractSink implements Configurable,
                             topic = event.getHeaders().get(TOPIC);
                         }
                     }
-                    logger.debug("Event is {}, topic = {} ",event, topic);
-
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Event is {}, topic = {} ",event, topic);
+                    }
                     if (event == null) {
                         continue;
                     }
