@@ -36,6 +36,7 @@ import org.apache.inlong.dataproxy.exception.ErrorCode;
 import org.apache.inlong.dataproxy.exception.MessageIDException;
 import org.jboss.netty.buffer.ChannelBuffer;
 import org.jboss.netty.channel.Channel;
+import org.jboss.netty.channel.MessageEvent;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.xerial.snappy.Snappy;
@@ -73,17 +74,17 @@ public class DefaultServiceDecoder implements ServiceDecoder {
 
     /**
      * extract bin heart beat data, message type is 8
-     *
      * @param resultMap
      * @param cb
      * @param channel
+     * @param msgEvent
      * @param totalDataLen
      * @return
      * @throws
      */
     private Map<String, Object> extractNewBinHB(Map<String, Object> resultMap,
-                                                ChannelBuffer cb, Channel channel,
-                                                int totalDataLen) throws Exception {
+            ChannelBuffer cb, Channel channel,
+            MessageEvent msgEvent, int totalDataLen) throws Exception {
         int msgHeadPos = cb.readerIndex() - 5;
 
         // check validation
@@ -96,7 +97,8 @@ public class DefaultServiceDecoder implements ServiceDecoder {
                 + attrLen + BIN_HB_FORMAT_SIZE)) || (msgMagic != BIN_MSG_MAGIC)) {
 
             LOG.error("err msg, bodyLen + attrLen > totalDataLen, "
-                            + "and bodyLen={},attrLen={},totalDataLen={},magic={};Connection info:{}",
+                            + "and bodyLen={},attrLen={},totalDataLen={},magic={};Connection "
+                            + "info:{}",
                     bodyLen, attrLen, totalDataLen, Integer.toHexString(msgMagic), channel.toString());
 
             return resultMap;
@@ -117,7 +119,8 @@ public class DefaultServiceDecoder implements ServiceDecoder {
     }
 
     private void handleDateTime(Map<String, String> commonAttrMap, Channel channel,
-        long uniq, long dataTime, int msgCount) {
+            MessageEvent msgEvent,
+            long uniq, long dataTime, int msgCount) {
         commonAttrMap.put(AttributeConstants.UNIQ_ID, String.valueOf(uniq));
         String time = "";
         if (commonAttrMap.containsKey(ConfigConstants.PKG_TIME_KEY)) {
@@ -127,7 +130,16 @@ public class DefaultServiceDecoder implements ServiceDecoder {
             time = String.valueOf(dataTime);
         }
         StringBuilder sidBuilder = new StringBuilder();
-        sidBuilder.append(channel.getRemoteAddress().toString()).append("#").append(time)
+        /*
+         * udp need use msgEvent get remote address
+         */
+        String remoteAddress = "";
+        if (channel != null && channel.getRemoteAddress() != null) {
+            remoteAddress = channel.getRemoteAddress().toString();
+        } else if (msgEvent != null && msgEvent.getRemoteAddress() != null) {
+            remoteAddress = msgEvent.getRemoteAddress().toString();
+        }
+        sidBuilder.append(remoteAddress).append("#").append(time)
             .append("#").append(uniq);
         commonAttrMap.put(AttributeConstants.SEQUENCE_ID, new String(sidBuilder));
 
@@ -222,18 +234,18 @@ public class DefaultServiceDecoder implements ServiceDecoder {
 
     /**
      * extract bin data, message type is 7
-     *
      * @param resultMap
      * @param cb
      * @param channel
+     * @param msgEvent
      * @param totalDataLen
      * @param msgType
      * @return
      * @throws Exception
      */
     private Map<String, Object> extractNewBinData(Map<String, Object> resultMap,
-                                                  ChannelBuffer cb, Channel channel,
-                                                  int totalDataLen, MsgType msgType) throws Exception {
+            ChannelBuffer cb, Channel channel, MessageEvent msgEvent,
+            int totalDataLen, MsgType msgType) throws Exception {
         int msgHeadPos = cb.readerIndex() - 5;
 
         int bodyLen = cb.getInt(msgHeadPos + BIN_MSG_BODYLEN_OFFSET);
@@ -255,8 +267,8 @@ public class DefaultServiceDecoder implements ServiceDecoder {
                             + ";Connection info:" + channel.toString()));
         }
 
-        int bidNum = cb.readUnsignedShort();
-        int tidNum = cb.readUnsignedShort();
+        int groupIdNum = cb.readUnsignedShort();
+        int streamIdNum = cb.readUnsignedShort();
         final int extendField = cb.readUnsignedShort();
         long dataTime = cb.readUnsignedInt();
         int msgCount = cb.readUnsignedShort();
@@ -294,44 +306,45 @@ public class DefaultServiceDecoder implements ServiceDecoder {
         }
 
         try {
-            handleDateTime(commonAttrMap, channel, uniq, dataTime, msgCount);
+            handleDateTime(commonAttrMap, channel, msgEvent, uniq, dataTime, msgCount);
             final boolean index = handleExtMap(commonAttrMap, cb, resultMap, extendField, msgHeadPos);
             ByteBuffer dataBuf = handleTrace(channel, cb, extendField, msgHeadPos,
                 totalDataLen, attrLen, strAttr, bodyLen);
 
-            String bid = null;
-            String tid = null;
+            String groupId = null;
+            String streamId = null;
 
-            if (commonAttrMap.containsKey(AttributeConstants.BUSINESS_ID)) {
-                bid = commonAttrMap.get(AttributeConstants.BUSINESS_ID);
+            if (commonAttrMap.containsKey(AttributeConstants.GROUP_ID)) {
+                groupId = commonAttrMap.get(AttributeConstants.GROUP_ID);
             }
             if (commonAttrMap.containsKey(AttributeConstants.INTERFACE_ID)) {
-                tid = commonAttrMap.get(AttributeConstants.INTERFACE_ID);
+                streamId = commonAttrMap.get(AttributeConstants.INTERFACE_ID);
             }
 
-            if ((bid != null) && (tid != null)) {
+            if ((groupId != null) && (streamId != null)) {
                 commonAttrMap.put(AttributeConstants.NUM2NAME, "FALSE");
                 dataBuf.putShort(BIN_MSG_EXTEND_OFFSET, (short) (extendField | 0x4));
             } else {
-                boolean hasNumBid = (((extendField & 0x4) >> 2) == 0x0);
-                if (hasNumBid && (0 != bidNum) && (0 != tidNum)) {
+                boolean hasNumGroupId = (((extendField & 0x4) >> 2) == 0x0);
+                if (hasNumGroupId && (0 != groupIdNum) && (0 != streamIdNum)) {
                     commonAttrMap.put(AttributeConstants.NUM2NAME, "TRUE");
-                    commonAttrMap.put(AttributeConstants.BID_NUM, String.valueOf(bidNum));
-                    commonAttrMap.put(AttributeConstants.TID_NUM, String.valueOf(tidNum));
+                    commonAttrMap.put(AttributeConstants.GROUPID_NUM, String.valueOf(groupIdNum));
+                    commonAttrMap.put(AttributeConstants.STREAMID_NUM, String.valueOf(streamIdNum));
                 }
             }
 
             if (MsgType.MSG_BIN_MULTI_BODY.equals(msgType) && !index) {
                 List<ProxyMessage> msgList = new ArrayList<>(1);
-                msgList.add(new ProxyMessage(bid, tid, commonAttrMap, dataBuf.array()));
+                msgList.add(new ProxyMessage(groupId, streamId, commonAttrMap, dataBuf.array()));
                 resultMap.put(ConfigConstants.MSG_LIST, msgList);
             } else if (MsgType.MSG_BIN_MULTI_BODY.equals(msgType)) {
                 List<ProxyMessage> msgList = new ArrayList<>(1);
-                msgList.add(new ProxyMessage(bid, tid, commonAttrMap,
+                msgList.add(new ProxyMessage(groupId, streamId, commonAttrMap,
                         (byte[]) resultMap.get(ConfigConstants.FILE_BODY)));
                 resultMap.put(ConfigConstants.MSG_LIST, msgList);
             }
         } catch (Exception ex) {
+            LOG.error("extractNewBinData has error! ex = {}", ex);
             cb.clear();
             throw new MessageIDException(uniq, ErrorCode.OTHER_ERROR, ex.getCause());
         }
@@ -341,18 +354,19 @@ public class DefaultServiceDecoder implements ServiceDecoder {
 
     /**
      * extract bin data, message type less than 7
-     *
      * @param resultMap
      * @param cb
      * @param channel
      * @param totalDataLen
+     * @param msgEvent
      * @param msgType
      * @return
      * @throws Exception
      */
     private Map<String, Object> extractDefaultData(Map<String, Object> resultMap,
-                                                   ChannelBuffer cb, Channel channel,
-                                                   int totalDataLen, MsgType msgType) throws Exception {
+            ChannelBuffer cb, Channel channel,
+            MessageEvent msgEvent,
+            int totalDataLen, MsgType msgType) throws Exception {
         int bodyLen = cb.readInt();
         if (bodyLen == 0) {
             throw new Exception(new Throwable("err msg,  bodyLen is empty" + ";"
@@ -411,8 +425,8 @@ public class DefaultServiceDecoder implements ServiceDecoder {
 
         // fill up attr map with some keys.
         commonAttrMap.put(AttributeConstants.RCV_TIME, String.valueOf(System.currentTimeMillis()));
-        String bid = commonAttrMap.get(AttributeConstants.BUSINESS_ID);
-        String tid = commonAttrMap.get(AttributeConstants.INTERFACE_ID);
+        String groupId = commonAttrMap.get(AttributeConstants.GROUP_ID);
+        String streamId = commonAttrMap.get(AttributeConstants.INTERFACE_ID);
 
         // add message count attr
         String cntStr = commonAttrMap.get(AttributeConstants.MESSAGE_COUNT);
@@ -433,12 +447,12 @@ public class DefaultServiceDecoder implements ServiceDecoder {
                 byte[] record = new byte[singleMsgLen];
                 bodyBuffer.get(record);
 
-                ProxyMessage message = new ProxyMessage(bid, tid, commonAttrMap, record);
+                ProxyMessage message = new ProxyMessage(groupId, streamId, commonAttrMap, record);
                 msgList.add(message);
             }
         } else {
             msgList = new ArrayList<>(1);
-            msgList.add(new ProxyMessage(bid, tid, commonAttrMap, bodyData));
+            msgList.add(new ProxyMessage(groupId, streamId, commonAttrMap, bodyData));
         }
         resultMap.put(ConfigConstants.MSG_LIST, msgList);
 
@@ -467,7 +481,8 @@ public class DefaultServiceDecoder implements ServiceDecoder {
      * +--------+--------+--------+----------------+--------+----------------+------------------------+
      */
     @Override
-    public Map<String, Object> extractData(ChannelBuffer cb, Channel channel) throws Exception {
+    public Map<String, Object> extractData(ChannelBuffer cb, Channel channel,
+            MessageEvent msgEvent) throws Exception {
         Map<String, Object> resultMap = new HashMap<String, Object>();
         if (null == cb) {
             LOG.error("cb == null");
@@ -494,14 +509,14 @@ public class DefaultServiceDecoder implements ServiceDecoder {
             }
             // if it's bin heart beat.
             if (MsgType.MSG_BIN_HEARTBEAT.equals(msgType)) {
-                return extractNewBinHB(resultMap, cb, channel, totalDataLen);
+                return extractNewBinHB(resultMap, cb, channel, msgEvent, totalDataLen);
             }
 
             if (msgType.getValue() >= MsgType.MSG_BIN_MULTI_BODY.getValue()) {
                 resultMap.put(ConfigConstants.COMPRESS_TYPE, (compressType != 0) ? "snappy" : "");
-                return extractNewBinData(resultMap, cb, channel, totalDataLen, msgType);
+                return extractNewBinData(resultMap, cb, channel, msgEvent, totalDataLen, msgType);
             } else {
-                return extractDefaultData(resultMap, cb, channel, totalDataLen, msgType);
+                return extractDefaultData(resultMap, cb, channel, msgEvent, totalDataLen, msgType);
             }
 
         } else {
