@@ -18,13 +18,10 @@
 package org.apache.inlong.dataproxy.source;
 
 import static org.apache.inlong.dataproxy.consts.AttributeConstants.SEPARATOR;
-import static org.apache.inlong.dataproxy.consts.ConfigConstants.SLA_METRIC_BID;
 import static org.apache.inlong.dataproxy.consts.ConfigConstants.SLA_METRIC_DATA;
+import static org.apache.inlong.dataproxy.consts.ConfigConstants.SLA_METRIC_GROUPID;
 import static org.apache.inlong.dataproxy.source.SimpleTcpSource.blacklist;
 
-import com.google.common.base.Joiner;
-import com.google.common.base.Splitter;
-
 import java.io.IOException;
 import java.net.SocketAddress;
 import java.nio.ByteBuffer;
@@ -34,20 +31,27 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import java.util.concurrent.atomic.AtomicReference;
+
 import org.apache.commons.lang.StringUtils;
 import org.apache.flume.ChannelException;
 import org.apache.flume.Event;
 import org.apache.flume.channel.ChannelProcessor;
 import org.apache.flume.event.EventBuilder;
-import org.apache.inlong.commons.msg.TDMsg1;
+import org.apache.flume.source.AbstractSource;
+import org.apache.inlong.commons.monitor.MonitorIndex;
+import org.apache.inlong.commons.monitor.MonitorIndexExt;
+import org.apache.inlong.commons.msg.InLongMsg;
 import org.apache.inlong.dataproxy.base.ProxyMessage;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.consts.AttributeConstants;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
 import org.apache.inlong.dataproxy.exception.ErrorCode;
 import org.apache.inlong.dataproxy.exception.MessageIDException;
+import org.apache.inlong.dataproxy.metrics.DataProxyMetricItem;
+import org.apache.inlong.dataproxy.metrics.DataProxyMetricItemSet;
+import org.apache.inlong.dataproxy.metrics.audit.AuditUtils;
+import org.apache.inlong.dataproxy.utils.NetworkUtils;
 import org.jboss.netty.buffer.ChannelBuffer;
 import org.jboss.netty.buffer.ChannelBuffers;
 import org.jboss.netty.channel.Channel;
@@ -60,19 +64,25 @@ import org.jboss.netty.channel.group.ChannelGroup;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.base.Joiner;
+import com.google.common.base.Splitter;
+
 /**
  * Server message handler
  *
  */
 public class ServerMessageHandler extends SimpleChannelHandler {
-
     private static final Logger logger = LoggerFactory.getLogger(ServerMessageHandler.class);
 
     private static final String DEFAULT_REMOTE_IP_VALUE = "0.0.0.0";
+
     private static final String DEFAULT_REMOTE_IDC_VALUE = "0";
+
     private static final ConfigManager configManager = ConfigManager.getInstance();
+
     private static final Joiner.MapJoiner mapJoiner = Joiner.on(AttributeConstants.SEPARATOR)
             .withKeyValueSeparator(AttributeConstants.KEY_VALUE_SEPARATOR);
+
     private static final Splitter.MapSplitter mapSplitter = Splitter
             .on(AttributeConstants.SEPARATOR)
             .trimResults().withKeyValueSeparator(AttributeConstants.KEY_VALUE_SEPARATOR);
@@ -84,6 +94,7 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                     return new SimpleDateFormat("yyyyMMddHHmm");
                 }
             };
+
     private static final ThreadLocal<SimpleDateFormat> dateFormator4Transfer =
             new ThreadLocal<SimpleDateFormat>() {
                 @Override
@@ -91,26 +102,44 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                     return new SimpleDateFormat("yyyyMMddHHmmss");
                 }
             };
+    private AbstractSource source;
 
     private final ChannelGroup allChannels;
+
     private int maxConnections = Integer.MAX_VALUE;
+
     private boolean filterEmptyMsg = false;
+
     private final boolean isCompressed;
+
     private final ChannelProcessor processor;
-    private final ServiceDecoder serviceProcessor;
+
+    private final ServiceDecoder serviceDecoder;
+
     private final String defaultTopic;
+
     private String defaultMXAttr = "m=3";
+
     private final ChannelBuffer heartbeatBuffer;
+
     private final String protocolType;
 
-    public ServerMessageHandler(ChannelProcessor processor, ServiceDecoder serProcessor,
-                                ChannelGroup allChannels,
-                                String topic, String attr, Boolean filterEmptyMsg, Integer maxMsgLength,
-                                Integer maxCons,
-                                Boolean isCompressed, String protocolType) {
 
-        this.processor = processor;
-        this.serviceProcessor = serProcessor;
+    private MonitorIndex monitorIndex;
+
+    private MonitorIndexExt monitorIndexExt;
+
+    //
+    private final DataProxyMetricItemSet metricItemSet;
+
+    public ServerMessageHandler(AbstractSource source, ServiceDecoder serviceDecoder,
+            ChannelGroup allChannels,
+            String topic, String attr, Boolean filterEmptyMsg,
+            Integer maxCons, Boolean isCompressed, MonitorIndex monitorIndex,
+            MonitorIndexExt monitorIndexExt, String protocolType) {
+        this.source = source;
+        this.processor = source.getChannelProcessor();
+        this.serviceDecoder = serviceDecoder;
         this.allChannels = allChannels;
         this.defaultTopic = topic;
         if (null != attr) {
@@ -122,11 +151,25 @@ public class ServerMessageHandler extends SimpleChannelHandler {
         this.heartbeatBuffer = ChannelBuffers.wrappedBuffer(new byte[]{0, 0, 0, 1, 1});
         this.maxConnections = maxCons;
         this.protocolType = protocolType;
+        if (source instanceof SimpleTcpSource) {
+            this.metricItemSet = ((SimpleTcpSource) source).getMetricItemSet();
+        } else {
+            this.metricItemSet = new DataProxyMetricItemSet(this.toString());
+        }
+        this.monitorIndex = monitorIndex;
+        this.monitorIndexExt = monitorIndexExt;
     }
 
     private String getRemoteIp(Channel channel) {
+        return getRemoteIp(channel, null);
+    }
+
+    private String getRemoteIp(Channel channel, SocketAddress remoteAddress) {
         String strRemoteIp = DEFAULT_REMOTE_IP_VALUE;
         SocketAddress remoteSocketAddress = channel.getRemoteAddress();
+        if (remoteSocketAddress == null) {
+            remoteSocketAddress = remoteAddress;
+        }
         if (null != remoteSocketAddress) {
             strRemoteIp = remoteSocketAddress.toString();
             try {
@@ -214,29 +257,29 @@ public class ServerMessageHandler extends SimpleChannelHandler {
         }
     }
 
-    private void checkBidInfo(ProxyMessage message, Map<String, String> commonAttrMap,
-        Map<String, String> attrMap, AtomicReference<String> topicInfo) {
-        String bid = message.getBid();
-        String tid;
-        if (null != bid) {
+    private void checkGroupIdInfo(ProxyMessage message, Map<String, String> commonAttrMap,
+            Map<String, String> attrMap, AtomicReference<String> topicInfo) {
+        String groupId = message.getGroupId();
+        String streamId = message.getStreamId();
+        if (null != groupId) {
             String from = commonAttrMap.get(AttributeConstants.FROM);
             if ("dc".equals(from)) {
-                String dcInterfaceId = message.getTid();
+                String dcInterfaceId = message.getStreamId();
                 if (StringUtils.isNotEmpty(dcInterfaceId)
-                    && configManager.getDcMappingProperties()
-                    .containsKey(dcInterfaceId.trim())) {
-                    bid = configManager.getDcMappingProperties()
-                        .get(dcInterfaceId.trim()).trim();
-                    message.setBid(bid);
+                        && configManager.getDcMappingProperties()
+                        .containsKey(dcInterfaceId.trim())) {
+                    groupId = configManager.getDcMappingProperties()
+                            .get(dcInterfaceId.trim()).trim();
+                    message.setGroupId(groupId);
                 }
             }
 
-            String value = configManager.getTopicProperties().get(bid);
+            String value = getTopic(groupId, streamId);
             if (StringUtils.isNotEmpty(value)) {
                 topicInfo.set(value.trim());
             }
 
-            Map<String, String> mxValue = configManager.getMxPropertiesMaps().get(bid);
+            Map<String, String> mxValue = configManager.getMxPropertiesMaps().get(groupId);
             if (mxValue != null && mxValue.size() != 0) {
                 message.getAttributeMap().putAll(mxValue);
             } else {
@@ -244,30 +287,30 @@ public class ServerMessageHandler extends SimpleChannelHandler {
             }
         } else {
             String num2name = commonAttrMap.get(AttributeConstants.NUM2NAME);
-            String bidNum = commonAttrMap.get(AttributeConstants.BID_NUM);
-            String tidNum = commonAttrMap.get(AttributeConstants.TID_NUM);
+            String groupIdNum = commonAttrMap.get(AttributeConstants.GROUPID_NUM);
+            String streamIdNum = commonAttrMap.get(AttributeConstants.STREAMID_NUM);
 
-            if (configManager.getBidMappingProperties() != null
-                && configManager.getTidMappingProperties() != null) {
-                bid = configManager.getBidMappingProperties().get(bidNum);
-                tid = (configManager.getTidMappingProperties().get(bidNum) == null)
-                    ? null : configManager.getTidMappingProperties().get(bidNum).get(tidNum);
-                if (bid != null && tid != null) {
+            if (configManager.getGroupIdMappingProperties() != null
+                    && configManager.getStreamIdMappingProperties() != null) {
+                groupId = configManager.getGroupIdMappingProperties().get(groupIdNum);
+                streamId = (configManager.getStreamIdMappingProperties().get(groupIdNum) == null)
+                        ? null : configManager.getStreamIdMappingProperties().get(groupIdNum).get(streamIdNum);
+                if (groupId != null && streamId != null) {
                     String enableTrans =
-                        (configManager.getBidEnableMappingProperties() == null)
-                            ? null : configManager.getBidEnableMappingProperties().get(bidNum);
+                            (configManager.getGroupIdEnableMappingProperties() == null)
+                                    ? null : configManager.getGroupIdEnableMappingProperties().get(groupIdNum);
                     if (("TRUE".equalsIgnoreCase(enableTrans) && "TRUE"
-                        .equalsIgnoreCase(num2name))) {
-                        String extraAttr = "bid=" + bid + "&" + "tid=" + tid;
+                            .equalsIgnoreCase(num2name))) {
+                        String extraAttr = "groupId=" + groupId + "&" + "streamId=" + streamId;
                         message.setData(newBinMsg(message.getData(), extraAttr));
                     }
 
-                    attrMap.put(AttributeConstants.BUSINESS_ID, bid);
-                    attrMap.put(AttributeConstants.INTERFACE_ID, tid);
-                    message.setBid(bid);
-                    message.setTid(tid);
+                    attrMap.put(AttributeConstants.GROUP_ID, groupId);
+                    attrMap.put(AttributeConstants.INTERFACE_ID, streamId);
+                    message.setGroupId(groupId);
+                    message.setStreamId(streamId);
 
-                    String value = configManager.getTopicProperties().get(bid);
+                    String value = getTopic(groupId, streamId);
                     if (StringUtils.isNotEmpty(value)) {
                         topicInfo.set(value.trim());
                     }
@@ -277,43 +320,43 @@ public class ServerMessageHandler extends SimpleChannelHandler {
     }
 
     private void updateMsgList(List<ProxyMessage> msgList, Map<String, String> commonAttrMap,
-        Map<String, HashMap<String, List<ProxyMessage>>> messageMap,
-        String strRemoteIP, MsgType msgType) {
+            Map<String, HashMap<String, List<ProxyMessage>>> messageMap,
+            String strRemoteIP, MsgType msgType) {
         for (ProxyMessage message : msgList) {
             Map<String, String> attrMap = message.getAttributeMap();
 
             String topic = this.defaultTopic;
 
             AtomicReference<String> topicInfo = new AtomicReference<>(topic);
-            checkBidInfo(message, commonAttrMap, attrMap, topicInfo);
+            checkGroupIdInfo(message, commonAttrMap, attrMap, topicInfo);
             topic = topicInfo.get();
 
-//                if(bid==null)bid="b_test";//default bid
+            //                if(groupId==null)groupId="b_test";//default groupId
 
             message.setTopic(topic);
             commonAttrMap.put(AttributeConstants.NODE_IP, strRemoteIP);
 
-            String bid = message.getBid();
-            String tid = message.getTid();
+            String groupId = message.getGroupId();
+            String streamId = message.getStreamId();
 
             // whether sla
-            if (SLA_METRIC_BID.equals(bid)) {
+            if (SLA_METRIC_GROUPID.equals(groupId)) {
                 commonAttrMap.put(SLA_METRIC_DATA, "true");
                 message.setTopic(SLA_METRIC_DATA);
             }
 
-            if (bid != null && tid != null) {
-                String tubeSwtichKey = bid + SEPARATOR + tid;
+            if (groupId != null && streamId != null) {
+                String tubeSwtichKey = groupId + SEPARATOR + streamId;
                 if (configManager.getTubeSwitchProperties().get(tubeSwtichKey) != null
-                    && "false".equals(configManager.getTubeSwitchProperties()
-                    .get(tubeSwtichKey).trim())) {
+                        && "false".equals(configManager.getTubeSwitchProperties()
+                        .get(tubeSwtichKey).trim())) {
                     continue;
                 }
             }
 
             if (!"pb".equals(attrMap.get(AttributeConstants.MESSAGE_TYPE))
-                && !MsgType.MSG_MULTI_BODY.equals(msgType)
-                && !MsgType.MSG_MULTI_BODY_ATTR.equals(msgType)) {
+                    && !MsgType.MSG_MULTI_BODY.equals(msgType)
+                    && !MsgType.MSG_MULTI_BODY_ATTR.equals(msgType)) {
                 byte[] data = message.getData();
                 if (data[data.length - 1] == '\n') {
                     int tripDataLen = data.length - 1;
@@ -326,48 +369,48 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                 }
             }
 
-            if (tid == null) {
-                tid = "";
+            if (streamId == null) {
+                streamId = "";
             }
-            HashMap<String, List<ProxyMessage>> tidMsgMap = messageMap
-                .computeIfAbsent(topic, k -> new HashMap<>());
-            List<ProxyMessage> tidMsgList = tidMsgMap
-                .computeIfAbsent(tid, k -> new ArrayList<>());
-            tidMsgList.add(message);
+            HashMap<String, List<ProxyMessage>> streamIdMsgMap = messageMap
+                    .computeIfAbsent(topic, k -> new HashMap<>());
+            List<ProxyMessage> streamIdMsgList = streamIdMsgMap
+                    .computeIfAbsent(streamId, k -> new ArrayList<>());
+            streamIdMsgList.add(message);
         }
     }
 
     private void formatMessagesAndSend(Map<String, String> commonAttrMap,
-        Map<String, HashMap<String, List<ProxyMessage>>> messageMap,
-        String strRemoteIP, MsgType msgType) throws MessageIDException {
+            Map<String, HashMap<String, List<ProxyMessage>>> messageMap,
+            String strRemoteIP, MsgType msgType) throws MessageIDException {
 
-        int tdMsgVer = 1;
+        int inLongMsgVer = 1;
         if (MsgType.MSG_MULTI_BODY_ATTR.equals(msgType)) {
-            tdMsgVer = 3;
+            inLongMsgVer = 3;
         } else if (MsgType.MSG_BIN_MULTI_BODY.equals(msgType)) {
-            tdMsgVer = 4;
+            inLongMsgVer = 4;
         }
 
         for (Map.Entry<String, HashMap<String, List<ProxyMessage>>> topicEntry : messageMap.entrySet()) {
-            for (Map.Entry<String, List<ProxyMessage>> tidEntry : topicEntry.getValue().entrySet()) {
+            for (Map.Entry<String, List<ProxyMessage>> streamIdEntry : topicEntry.getValue().entrySet()) {
 
-                TDMsg1 tdMsg = TDMsg1.newTDMsg(this.isCompressed, tdMsgVer);
+                InLongMsg inLongMsg = InLongMsg.newInLongMsg(this.isCompressed, inLongMsgVer);
                 Map<String, String> headers = new HashMap<String, String>();
-                for (ProxyMessage message : tidEntry.getValue()) {
+                for (ProxyMessage message : streamIdEntry.getValue()) {
                     if (MsgType.MSG_MULTI_BODY_ATTR.equals(msgType) || MsgType.MSG_MULTI_BODY.equals(msgType)) {
                         message.getAttributeMap().put(AttributeConstants.MESSAGE_COUNT, String.valueOf(1));
-                        tdMsg.addMsg(mapJoiner.join(message.getAttributeMap()), message.getData());
+                        inLongMsg.addMsg(mapJoiner.join(message.getAttributeMap()), message.getData());
                     } else if (MsgType.MSG_BIN_MULTI_BODY.equals(msgType)) {
-                        tdMsg.addMsg(message.getData());
+                        inLongMsg.addMsg(message.getData());
                     } else {
-                        tdMsg.addMsg(mapJoiner.join(message.getAttributeMap()), message.getData());
+                        inLongMsg.addMsg(mapJoiner.join(message.getAttributeMap()), message.getData());
                     }
                 }
 
-                long pkgTimeInMillis = tdMsg.getCreatetime();
+                long pkgTimeInMillis = inLongMsg.getCreatetime();
                 String pkgTimeStr = dateFormator.get().format(pkgTimeInMillis);
 
-                if (tdMsgVer == 4) {
+                if (inLongMsgVer == 4) {
                     if (commonAttrMap.containsKey(ConfigConstants.PKG_TIME_KEY)) {
                         pkgTimeStr = commonAttrMap.get(ConfigConstants.PKG_TIME_KEY);
                     } else {
@@ -382,22 +425,23 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                 }
 
                 headers.put(ConfigConstants.TOPIC_KEY, topicEntry.getKey());
-                headers.put(AttributeConstants.INTERFACE_ID, tidEntry.getKey());
+                headers.put(AttributeConstants.GROUP_ID,
+                        streamIdEntry.getValue().get(0).getGroupId());
+                headers.put(AttributeConstants.INTERFACE_ID, streamIdEntry.getKey());
                 headers.put(ConfigConstants.REMOTE_IP_KEY, strRemoteIP);
                 headers.put(ConfigConstants.REMOTE_IDC_KEY, DEFAULT_REMOTE_IDC_VALUE);
                 // every message share the same msg cnt? what if msgType = 5
                 String proxyMetricMsgCnt = commonAttrMap.get(AttributeConstants.MESSAGE_COUNT);
                 headers.put(ConfigConstants.MSG_COUNTER_KEY, proxyMetricMsgCnt);
 
-                byte[] data = tdMsg.buildArray();
+                byte[] data = inLongMsg.buildArray();
                 headers.put(ConfigConstants.TOTAL_LEN, String.valueOf(data.length));
 
                 String sequenceId = commonAttrMap.get(AttributeConstants.SEQUENCE_ID);
                 if (StringUtils.isNotEmpty(sequenceId)) {
-
                     StringBuilder sidBuilder = new StringBuilder();
-                    sidBuilder.append(topicEntry.getKey()).append(SEPARATOR).append(tidEntry.getKey())
-                        .append(SEPARATOR).append(sequenceId);
+                    sidBuilder.append(topicEntry.getKey()).append(SEPARATOR).append(streamIdEntry.getKey())
+                            .append(SEPARATOR).append(sequenceId);
                     headers.put(ConfigConstants.SEQUENCE_ID, sidBuilder.toString());
                 }
 
@@ -410,19 +454,34 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                 } catch (Exception e1) {
                     long uniqVal = Long.parseLong(commonAttrMap.get(AttributeConstants.UNIQ_ID));
                     throw new MessageIDException(uniqVal,
-                        ErrorCode.DT_ERROR,
-                        new Throwable("attribute dt=" + headers.get(AttributeConstants.DATA_TIME
-                            + " has error, detail is: topic=" + topicEntry.getKey() + "&tid="
-                            + tidEntry.getKey() + "&NodeIP=" + strRemoteIP), e1));
+                            ErrorCode.DT_ERROR,
+                            new Throwable("attribute dt=" + headers.get(AttributeConstants.DATA_TIME
+                                    + " has error, detail is: topic=" + topicEntry.getKey() + "&streamId="
+                                    + streamIdEntry.getKey() + "&NodeIP=" + strRemoteIP), e1));
                 }
 
                 dtten = dtten / 1000 / 60 / 10;
                 dtten = dtten * 1000 * 60 * 10;
+                StringBuilder newbase = new StringBuilder();
+                newbase.append(protocolType).append(SEPARATOR)
+                        .append(topicEntry.getKey()).append(SEPARATOR)
+                        .append(streamIdEntry.getKey()).append(SEPARATOR)
+                        .append(strRemoteIP).append(SEPARATOR)
+                        .append(NetworkUtils.getLocalIp()).append(SEPARATOR)
+                        .append(new SimpleDateFormat("yyyyMMddHHmm")
+                                .format(dtten)).append(SEPARATOR).append(pkgTimeStr);
                 try {
                     processor.processEvent(event);
+                    monitorIndexExt.incrementAndGet("EVENT_SUCCESS");
+                    this.addMetric(true, data.length, event);
+                    monitorIndex.addAndGet(new String(newbase),
+                            Integer.parseInt(proxyMetricMsgCnt), 1, data.length, 0);
                 } catch (Throwable ex) {
                     logger.error("Error writting to channel,data will discard.", ex);
-
+                    monitorIndexExt.incrementAndGet("EVENT_DROPPED");
+                    monitorIndex.addAndGet(new String(newbase), 0,0,0,
+                            Integer.parseInt(proxyMetricMsgCnt));
+                    this.addMetric(false, data.length, event);
                     throw new ChannelException("ProcessEvent error can't write event to channel.");
                 }
             }
@@ -430,15 +489,15 @@ public class ServerMessageHandler extends SimpleChannelHandler {
     }
 
     private void responsePackage(Map<String, String> commonAttrMap,
-        Map<String, Object> resultMap,
-        Channel remoteChannel,
-        SocketAddress remoteSocketAddress,
-        MsgType msgType) throws Exception {
+            Map<String, Object> resultMap,
+            Channel remoteChannel,
+            SocketAddress remoteSocketAddress,
+            MsgType msgType) throws Exception {
         if (!commonAttrMap.containsKey("isAck") || "true".equals(commonAttrMap.get("isAck"))) {
             if (MsgType.MSG_ACK_SERVICE.equals(msgType) || MsgType.MSG_ORIGINAL_RETURN
-                .equals(msgType)
-                || MsgType.MSG_MULTI_BODY.equals(msgType) || MsgType.MSG_MULTI_BODY_ATTR
-                .equals(msgType)) {
+                    .equals(msgType)
+                    || MsgType.MSG_MULTI_BODY.equals(msgType) || MsgType.MSG_MULTI_BODY_ATTR
+                    .equals(msgType)) {
                 byte[] backAttr = mapJoiner.join(commonAttrMap).getBytes(StandardCharsets.UTF_8);
                 byte[] backBody = null;
 
@@ -463,14 +522,14 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                     } else {
                         String backAttrStr = new String(backAttr, StandardCharsets.UTF_8);
                         logger.warn(
-                            "the send buffer1 is full, so disconnect it!please check remote client"
-                                + "; Connection info:"
-                                + remoteChannel + ";attr is " + backAttrStr);
+                                "the send buffer1 is full, so disconnect it!please check remote client"
+                                        + "; Connection info:"
+                                        + remoteChannel + ";attr is " + backAttrStr);
                         throw new Exception(new Throwable(
-                            "the send buffer1 is full, so disconnect it!please check remote client"
-                                +
-                                "; Connection info:" + remoteChannel + ";attr is "
-                                + backAttrStr));
+                                "the send buffer1 is full, so disconnect it!please check remote client"
+                                        +
+                                        "; Connection info:" + remoteChannel + ";attr is "
+                                        + backAttrStr));
                     }
                 }
             } else if (MsgType.MSG_BIN_MULTI_BODY.equals(msgType)) {
@@ -508,12 +567,12 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                     remoteChannel.write(binBuffer, remoteSocketAddress);
                 } else {
                     logger.warn(
-                        "the send buffer2 is full, so disconnect it!please check remote client"
-                            + "; Connection info:" + remoteChannel + ";attr is "
-                            + backattrs);
+                            "the send buffer2 is full, so disconnect it!please check remote client"
+                                    + "; Connection info:" + remoteChannel + ";attr is "
+                                    + backattrs);
                     throw new Exception(new Throwable(
-                        "the send buffer2 is full,so disconnect it!please check remote client, Connection info:"
-                            + remoteChannel + ";attr is " + backattrs));
+                            "the send buffer2 is full,so disconnect it!please check remote client, Connection info:"
+                                    + remoteChannel + ";attr is " + backattrs));
                 }
             }
         }
@@ -521,43 +580,48 @@ public class ServerMessageHandler extends SimpleChannelHandler {
 
     @Override
     public void messageReceived(ChannelHandlerContext ctx, MessageEvent e) throws Exception {
-        logger.info("message received");
+        logger.debug("message received");
         if (e == null) {
             logger.error("get null messageevent, just skip");
+            this.addMetric(false, 0, null);
             return;
         }
         ChannelBuffer cb = ((ChannelBuffer) e.getMessage());
-        String strRemoteIP = getRemoteIp(e.getChannel());
+        String strRemoteIP = getRemoteIp(e.getChannel(), e.getRemoteAddress());
         SocketAddress remoteSocketAddress = e.getRemoteAddress();
         int len = cb.readableBytes();
         if (len == 0 && this.filterEmptyMsg) {
             logger.warn("skip empty msg.");
             cb.clear();
+            this.addMetric(false, 0, null);
             return;
         }
 
         Channel remoteChannel = e.getChannel();
         Map<String, Object> resultMap = null;
         try {
-            resultMap = serviceProcessor.extractData(cb, remoteChannel);
+            resultMap = serviceDecoder.extractData(cb, remoteChannel, e);
         } catch (MessageIDException ex) {
+            logger.error("MessageIDException ex = {}", ex);
+            this.addMetric(false, 0, null);
             throw new IOException(ex.getCause());
         }
 
         if (resultMap == null) {
             logger.info("result is null");
+            this.addMetric(false, 0, null);
             return;
         }
 
         MsgType msgType = (MsgType) resultMap.get(ConfigConstants.MSG_TYPE);
         if (MsgType.MSG_HEARTBEAT.equals(msgType)) {
             remoteChannel.write(heartbeatBuffer, remoteSocketAddress);
+            this.addMetric(false, 0, null);
             return;
         }
 
         if (MsgType.MSG_BIN_HEARTBEAT.equals(msgType)) {
-//            ChannelBuffer binBuffer = getBinHeart(resultMap,msgType);
-//            remoteChannel.write(binBuffer, remoteSocketAddress);
+            this.addMetric(false, 0, null);
             return;
         }
 
@@ -573,27 +637,26 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                 && !commonAttrMap.containsKey(ConfigConstants.MINUTE_CHECK_DATA)) {
             Map<String, HashMap<String, List<ProxyMessage>>> messageMap =
                     new HashMap<String, HashMap<String, List<ProxyMessage>>>(
-                    msgList.size());
+                            msgList.size());
 
             updateMsgList(msgList, commonAttrMap, messageMap, strRemoteIP, msgType);
 
             formatMessagesAndSend(commonAttrMap, messageMap, strRemoteIP, msgType);
 
         } else if (msgList != null && commonAttrMap.containsKey(ConfigConstants.FILE_CHECK_DATA)) {
-//            logger.info("i am in FILE_CHECK_DATA ");
             Map<String, String> headers = new HashMap<String, String>();
             headers.put("msgtype", "filestatus");
             headers.put(ConfigConstants.FILE_CHECK_DATA,
                     "true");
             for (ProxyMessage message : msgList) {
                 byte[] body = message.getData();
-//                logger.info("data:"+new String(body));
                 Event event = EventBuilder.withBody(body, headers);
                 try {
                     processor.processEvent(event);
+                    this.addMetric(true, body.length, event);
                 } catch (Throwable ex) {
                     logger.error("Error writing to controller,data will discard.", ex);
-
+                    this.addMetric(false, body.length, event);
                     throw new ChannelException(
                             "Process Controller Event error can't write event to channel.");
                 }
@@ -607,13 +670,13 @@ public class ServerMessageHandler extends SimpleChannelHandler {
                     "true");
             for (ProxyMessage message : msgList) {
                 byte[] body = message.getData();
-//                logger.info("data:"+new String(body));
                 Event event = EventBuilder.withBody(body, headers);
                 try {
                     processor.processEvent(event);
+                    this.addMetric(true, body.length, event);
                 } catch (Throwable ex) {
                     logger.error("Error writing to controller,data will discard.", ex);
-
+                    this.addMetric(false, body.length, event);
                     throw new ChannelException(
                             "Process Controller Event error can't write event to channel.");
                 }
@@ -625,10 +688,70 @@ public class ServerMessageHandler extends SimpleChannelHandler {
     @Override
     public void exceptionCaught(ChannelHandlerContext ctx, ExceptionEvent e) throws Exception {
         logger.error("exception caught", e.getCause());
+        monitorIndexExt.incrementAndGet("EVENT_OTHEREXP");
     }
 
     @Override
     public void channelClosed(ChannelHandlerContext ctx, ChannelStateEvent e) throws Exception {
         logger.error("channel closed {}", ctx.getChannel());
+        super.channelClosed(ctx, e);
+        try {
+            e.getChannel().disconnect();
+            e.getChannel().close();
+        } catch (Exception ex) {
+            //
+        }
+        allChannels.remove(e.getChannel());
+    }
+
+    /**
+     * get topic
+     */
+    private String getTopic(String groupId) {
+        return getTopic(groupId, null);
+    }
+
+    /**
+     * get topic
+     */
+    private String getTopic(String groupId, String streamId) {
+        String topic = null;
+        if (StringUtils.isNotEmpty(groupId)) {
+            if (StringUtils.isNotEmpty(streamId)) {
+                topic = configManager.getTopicProperties().get(groupId + "/" + streamId);
+            }
+            if (StringUtils.isEmpty(topic)) {
+                topic = configManager.getTopicProperties().get(groupId);
+            }
+        }
+        if (logger.isDebugEnabled()) {
+            logger.debug("Get topic by groupId = {} , streamId = {}", groupId, streamId);
+        }
+        return topic;
+    }
+
+    /**
+     * addMetric
+     * 
+     * @param result
+     * @param size
+     * @param event
+     */
+    private void addMetric(boolean result, long size, Event event) {
+        Map<String, String> dimensions = new HashMap<>();
+        dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, "DataProxy");
+        dimensions.put(DataProxyMetricItem.KEY_SOURCE_ID, source.getName());
+        dimensions.put(DataProxyMetricItem.KEY_SOURCE_DATA_ID, source.getName());
+        DataProxyMetricItem.fillInlongId(event, dimensions);
+        DataProxyMetricItem.fillAuditFormatTime(event, dimensions);
+        DataProxyMetricItem metricItem = this.metricItemSet.findMetricItem(dimensions);
+        if (result) {
+            metricItem.readSuccessCount.incrementAndGet();
+            metricItem.readSuccessSize.addAndGet(size);
+            AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_READ_SUCCESS, event);
+        } else {
+            metricItem.readFailCount.incrementAndGet();
+            metricItem.readFailSize.addAndGet(size);
+        }
     }
 }
