@@ -26,10 +26,10 @@ import lombok.Data;
 @Data
 public class DataStreamBaseInfo {
 
-    @ApiModelProperty(value = "Business identifier")
-    private String businessIdentifier;
+    @ApiModelProperty(value = "Business group id")
+    private String inlongGroupId;
 
-    @ApiModelProperty(value = "Data stream identifier")
-    private String dataStreamIdentifier;
+    @ApiModelProperty(value = "Data stream id")
+    private String inlongStreamId;
 
 }
