@@ -67,22 +67,19 @@ import org.springframework.stereotype.Repository;
 @SuppressWarnings("UnstableApiUsage")
 @Repository(value = "dataProxyConfigRepository")
 public class DataProxyConfigRepository implements IRepository {
-    private static final Logger LOGGER = LoggerFactory.getLogger(DataProxyConfigRepository.class);
+
     public static final Splitter.MapSplitter MAP_SPLITTER = Splitter.on(SEPARATOR).trimResults()
             .withKeyValueSeparator(KEY_VALUE_SEPARATOR);
+    private static final Logger LOGGER = LoggerFactory.getLogger(DataProxyConfigRepository.class);
+    private static final Gson gson = new Gson();
+
+    private final Map<String, ProxyClusterObject> proxyClusterMap = new HashMap<>();
+    private final Map<String, CacheClusterObject> cacheClusterMap = new HashMap<>();
+    private Map<String, DataProxyClusterSet> clusterSets = new HashMap<>();
+    private long reloadInterval;
+
     @Autowired
     private ClusterSetMapper clusterSetMapper;
-    // Map<setName, DataProxyClusterSet>
-    private Map<String, DataProxyClusterSet> clusterSets = new HashMap<>();
-
-    // Map<proxyClusterName, ProxyClusterObject>
-    private final Map<String, ProxyClusterObject> proxyClusterMap = new HashMap<>();
-    // Map<cacheClusterName, CacheClusterObject>
-    private final Map<String, CacheClusterObject> cacheClusterMap = new HashMap<>();
-
-    private long  reloadInterval;
-
-    private Gson gson = new Gson();
 
     @PostConstruct
     public void initialize() {
@@ -115,34 +112,21 @@ public class DataProxyConfigRepository implements IRepository {
             setObj.getCacheClusterSet().setType(set.getMiddlewareType());
             newClusterSets.put(setName, setObj);
         }
-        //
         this.proxyClusterMap.clear();
         this.cacheClusterMap.clear();
-        //
         this.reloadCacheCluster(newClusterSets);
-        //
         this.reloadCacheClusterExt(newClusterSets);
-        //
         this.reloadCacheTopic(newClusterSets);
-        //
         this.reloadProxyCluster(newClusterSets);
-        //
         this.reloadFlumeChannel(newClusterSets);
-        //
         this.reloadFlumeChannelExt(newClusterSets);
-        //
         this.reloadFlumeSource(newClusterSets);
-        //
         this.reloadFlumeSourceExt(newClusterSets);
-        //
         this.reloadFlumeSink(newClusterSets);
-        //
         this.reloadFlumeSinkExt(newClusterSets);
         // reload inlongid
         this.reloadInlongId(newClusterSets);
-        //
         this.reloadProxy2Cache(newClusterSets);
-        //
         this.generateClusterJson(newClusterSets);
 
         // replace
@@ -162,7 +146,7 @@ public class DataProxyConfigRepository implements IRepository {
 
     /**
      * get clusterSets
-     * 
+     *
      * @return the clusterSets
      */
     public Map<String, DataProxyClusterSet> getClusterSets() {
@@ -170,19 +154,16 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadCacheCluster
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadCacheCluster(Map<String, DataProxyClusterSet> newClusterSets) {
         for (CacheCluster cacheCluster : clusterSetMapper.selectCacheCluster()) {
-            //
             CacheClusterObject obj = new CacheClusterObject();
             obj.setName(cacheCluster.getClusterName());
             obj.setZone(cacheCluster.getZone());
             cacheClusterMap.put(obj.getName(), obj);
-            //
             String setName = cacheCluster.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
             setObj.getCacheClusterSet().getCacheClusters().add(obj);
@@ -191,7 +172,7 @@ public class DataProxyConfigRepository implements IRepository {
 
     /**
      * getOrCreateDataProxyClusterSet
-     * 
+     *
      * @param clusterSets
      * @param setName
      * @return
@@ -208,9 +189,8 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadCacheClusterExt
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadCacheClusterExt(Map<String, DataProxyClusterSet> newClusterSets) {
@@ -224,18 +204,15 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadCacheTopic
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadCacheTopic(Map<String, DataProxyClusterSet> newClusterSets) {
         for (CacheTopic cacheTopic : clusterSetMapper.selectCacheTopic()) {
-            //
             CacheTopicObject obj = new CacheTopicObject();
             obj.setTopic(cacheTopic.getTopicName());
             obj.setPartitionNum(cacheTopic.getPartitionNum());
-            //
             String setName = cacheTopic.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
             setObj.getCacheClusterSet().getTopics().add(obj);
@@ -243,15 +220,13 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadProxyCluster
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadProxyCluster(Map<String, DataProxyClusterSet> newClusterSets) {
         for (ProxyCluster proxyCluster : clusterSetMapper.selectProxyCluster()) {
             String setName = proxyCluster.getSetName();
-            //
             ProxyClusterObject obj = new ProxyClusterObject();
             obj.setName(proxyCluster.getClusterName());
             obj.setSetName(setName);
@@ -263,14 +238,12 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeChannel
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeChannel(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeChannel flumeChannel : clusterSetMapper.selectFlumeChannel()) {
-            //
             ProxyChannel obj = new ProxyChannel();
             obj.setName(flumeChannel.getChannelName());
             obj.setType(flumeChannel.getType());
@@ -281,16 +254,14 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeChannelExt
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeChannelExt(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeChannelExt ext : clusterSetMapper.selectFlumeChannelExt()) {
             String setName = ext.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
-            //
             ProxyChannel obj = setObj.getProxyChannelMap().get(ext.getParentName());
             if (obj != null) {
                 obj.getParams().put(ext.getKeyName(), ext.getKeyValue());
@@ -299,22 +270,18 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeSource
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeSource(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeSource flumeSource : clusterSetMapper.selectFlumeSource()) {
-            //
             ProxySource obj = new ProxySource();
             obj.setName(flumeSource.getSourceName());
             obj.setSelectorType(flumeSource.getSelectorType());
             obj.setType(flumeSource.getType());
-            //
             String channels = flumeSource.getChannels();
             obj.getChannels().addAll(Arrays.asList(channels.split("\\s+")));
-            //
             String setName = flumeSource.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
             setObj.getProxySourceMap().put(obj.getName(), obj);
@@ -322,16 +289,14 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeSourceExt
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeSourceExt(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeSourceExt ext : clusterSetMapper.selectFlumeSourceExt()) {
             String setName = ext.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
-            //
             ProxySource obj = setObj.getProxySourceMap().get(ext.getParentName());
             if (obj != null) {
                 obj.getParams().put(ext.getKeyName(), ext.getKeyValue());
@@ -340,19 +305,16 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeSink
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeSink(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeSink flumeSink : clusterSetMapper.selectFlumeSink()) {
-            //
             ProxySink obj = new ProxySink();
             obj.setName(flumeSink.getSinkName());
             obj.setType(flumeSink.getType());
             obj.setChannel(flumeSink.getChannel());
-            //
             String setName = flumeSink.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
             setObj.getProxySinkMap().put(obj.getName(), obj);
@@ -360,16 +322,14 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadFlumeSinkExt
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadFlumeSinkExt(Map<String, DataProxyClusterSet> newClusterSets) {
         for (FlumeSinkExt ext : clusterSetMapper.selectFlumeSinkExt()) {
             String setName = ext.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
-            //
             ProxySink obj = setObj.getProxySinkMap().get(ext.getParentName());
             if (obj != null) {
                 obj.getParams().put(ext.getKeyName(), ext.getKeyValue());
@@ -378,14 +338,12 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadInlongId
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadInlongId(Map<String, DataProxyClusterSet> newClusterSets) {
         for (InLongId inlongId : clusterSetMapper.selectInlongId()) {
-            //
             InLongIdObject obj = new InLongIdObject();
             obj.setInlongId(inlongId.getInlongId());
             obj.setTopic(inlongId.getTopic());
@@ -400,9 +358,8 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * reloadInlongId
-     * 
+     *
      * @param newClusterSets
      */
     private void reloadProxy2Cache(Map<String, DataProxyClusterSet> newClusterSets) {
@@ -417,18 +374,15 @@ public class DataProxyConfigRepository implements IRepository {
             if (cacheObj == null) {
                 continue;
             }
-            //
             String setName = proxyObj.getSetName();
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
-            //
             setObj.addProxy2Cache(proxyClusterName, cacheClusterName);
         }
     }
 
     /**
-     * 
      * generateClusterJson
-     * 
+     *
      * @param newClusterSets
      */
     private void generateClusterJson(Map<String, DataProxyClusterSet> newClusterSets) {
@@ -471,14 +425,13 @@ public class DataProxyConfigRepository implements IRepository {
     }
 
     /**
-     * 
      * getDataProxyClusterSet
-     * 
+     *
      * @param setName
      * @return
      */
     public DataProxyClusterSet getDataProxyClusterSet(String setName) {
-        DataProxyClusterSet setObj = this.clusterSets.get(setName);
-        return setObj;
+        return this.clusterSets.get(setName);
     }
+
 }
