@@ -21,9 +21,11 @@ import static java.util.stream.Collectors.toList;
 
 import java.util.ArrayList;
 import java.util.List;
-import lombok.extern.slf4j.Slf4j;
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.inlong.manager.common.enums.BizConstant;
 import org.apache.inlong.manager.common.enums.EntityStatus;
-import org.apache.inlong.manager.common.pojo.datastorage.StorageHiveSortInfo;
+import org.apache.inlong.manager.common.exceptions.WorkflowException;
+import org.apache.inlong.manager.common.pojo.datastorage.StorageHiveDTO;
 import org.apache.inlong.manager.common.pojo.query.ColumnInfoBean;
 import org.apache.inlong.manager.common.pojo.query.DatabaseQueryBean;
 import org.apache.inlong.manager.common.pojo.query.hive.HiveColumnQueryBean;
@@ -32,34 +34,53 @@ import org.apache.inlong.manager.dao.entity.StorageHiveFieldEntity;
 import org.apache.inlong.manager.dao.mapper.StorageHiveFieldEntityMapper;
 import org.apache.inlong.manager.service.core.DataSourceService;
 import org.apache.inlong.manager.service.core.StorageService;
-import org.apache.inlong.manager.workflow.exception.WorkflowException;
+import org.apache.inlong.manager.service.core.impl.StorageHiveOperation;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
 /**
  * Create hive table operation
  */
-@Slf4j
 @Component
 public class HiveTableOperator {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(StorageHiveOperation.class);
+
     @Autowired
     private StorageService storageService;
-    @Autowired
-    private DataSourceService<DatabaseQueryBean, HiveTableQueryBean> dataSourceService;
-
     @Autowired
     private StorageHiveFieldEntityMapper hiveFieldMapper;
+    @Autowired
+    private DataSourceService<DatabaseQueryBean, HiveTableQueryBean> dataSourceService;
 
     /**
      * Create hive table according to the groupId and hive config
      */
-    public void createHiveTable(String groupId, StorageHiveSortInfo hiveConfig) {
-        if (log.isDebugEnabled()) {
-            log.debug("begin create hive table for business={}, hiveConfig={}", groupId, hiveConfig);
+    public void createHiveResource(String groupId, List<StorageHiveDTO> configList) {
+        if (CollectionUtils.isEmpty(configList)) {
+            LOGGER.warn("no hive config, skip to create");
+            return;
+        }
+        for (StorageHiveDTO config : configList) {
+            if (EntityStatus.DATA_STORAGE_CONFIG_SUCCESSFUL.getCode().equals(config.getStatus())) {
+                LOGGER.warn("hive [" + config.getId() + "] already success, skip to create");
+                continue;
+            } else if (BizConstant.DISABLE_CREATE_TABLE.equals(config.getEnableCreateTable())) {
+                LOGGER.warn("create table was disable, skip to create table for hive [" + config.getId() + "]");
+                continue;
+            }
+            this.createTable(groupId, config);
+        }
+    }
+
+    private void createTable(String groupId, StorageHiveDTO config) {
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("begin create hive table for business={}, config={}", groupId, config);
         }
 
-        HiveTableQueryBean tableBean = getTableQueryBean(hiveConfig);
+        HiveTableQueryBean tableBean = getTableQueryBean(config);
         try {
             // create database if not exists
             dataSourceService.createDb(tableBean);
@@ -78,22 +99,22 @@ public class HiveTableOperator {
                     dataSourceService.createColumn(tableBean);
                 }
             }
-            storageService.updateHiveStatusById(hiveConfig.getId(),
+            storageService.updateHiveStatusById(config.getId(),
                     EntityStatus.DATA_STORAGE_CONFIG_SUCCESSFUL.getCode(), "create hive table success");
         } catch (Throwable e) {
-            log.error("create hive table error, ", e);
-            storageService.updateHiveStatusById(hiveConfig.getId(),
+            LOGGER.error("create hive table error, ", e);
+            storageService.updateHiveStatusById(config.getId(),
                     EntityStatus.DATA_STORAGE_CONFIG_FAILED.getCode(), e.getMessage());
             throw new WorkflowException("create hive table failed, reason: " + e.getMessage());
         }
 
-        log.info("finish create hive table for business {} ", groupId);
+        LOGGER.info("success create hive table for data group [" + groupId + "]");
     }
 
-    protected HiveTableQueryBean getTableQueryBean(StorageHiveSortInfo hiveConfig) {
-        String groupId = hiveConfig.getInlongGroupId();
-        String streamId = hiveConfig.getInlongStreamId();
-        log.info("begin to get table query bean for groupId={}, streamId={}", groupId, streamId);
+    protected HiveTableQueryBean getTableQueryBean(StorageHiveDTO config) {
+        String groupId = config.getInlongGroupId();
+        String streamId = config.getInlongStreamId();
+        LOGGER.info("begin to get table query bean for groupId={}, streamId={}", groupId, streamId);
 
         List<StorageHiveFieldEntity> fieldEntities = hiveFieldMapper.selectHiveFields(groupId, streamId);
 
@@ -107,31 +128,33 @@ public class HiveTableOperator {
         }
 
         // set partition field and type
-        String partitionField = hiveConfig.getPrimaryPartition();
+        String partitionField = config.getPrimaryPartition();
         if (partitionField != null) {
             HiveColumnQueryBean partColumn = new HiveColumnQueryBean();
             partColumn.setPartition(true);
             partColumn.setColumnName(partitionField);
-            partColumn.setColumnType("string"); // currently, only supports 'string' type
+            // currently, only supports 'string' type
+            partColumn.setColumnType("string");
             columnQueryBeans.add(partColumn);
         }
 
         HiveTableQueryBean queryBean = new HiveTableQueryBean();
         queryBean.setColumns(columnQueryBeans);
         // set terminated symbol
-        if (hiveConfig.getTargetSeparator() != null) {
-            char ch = (char) Integer.parseInt(hiveConfig.getTargetSeparator());
+        if (config.getTargetSeparator() != null) {
+            char ch = (char) Integer.parseInt(config.getTargetSeparator());
             queryBean.setFieldTerSymbol(String.valueOf(ch));
         }
-        queryBean.setUsername(hiveConfig.getUsername());
-        queryBean.setPassword(hiveConfig.getPassword());
-        queryBean.setTableName(hiveConfig.getTableName());
-        queryBean.setDbName(hiveConfig.getDbName());
-        queryBean.setJdbcUrl(hiveConfig.getJdbcUrl());
+        queryBean.setUsername(config.getUsername());
+        queryBean.setPassword(config.getPassword());
+        queryBean.setTableName(config.getTableName());
+        queryBean.setDbName(config.getDbName());
+        queryBean.setJdbcUrl(config.getJdbcUrl());
 
-        if (log.isDebugEnabled()) {
-            log.debug("success to get table query bean={}", queryBean);
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("success to get table query bean={}", queryBean);
         }
         return queryBean;
     }
+
 }
