@@ -27,30 +27,31 @@ import java.util.Map;
 import java.util.function.Consumer;
 import java.util.stream.Collectors;
 import javax.annotation.PostConstruct;
+import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.service.workflow.WorkflowTaskExecuteLog.ListenerExecutorLog;
 import org.apache.inlong.manager.service.workflow.WorkflowTaskExecuteLog.TaskExecutorLog;
-import org.apache.inlong.manager.workflow.core.QueryService;
-import org.apache.inlong.manager.workflow.core.WorkflowEngine;
-import org.apache.inlong.manager.workflow.exception.WorkflowNoRollbackException;
-import org.apache.inlong.manager.workflow.model.TaskState;
-import org.apache.inlong.manager.workflow.model.definition.Process;
-import org.apache.inlong.manager.workflow.model.definition.ProcessForm;
-import org.apache.inlong.manager.workflow.model.definition.TaskForm;
-import org.apache.inlong.manager.workflow.model.definition.UserTask;
-import org.apache.inlong.manager.workflow.model.instance.ProcessInstance;
-import org.apache.inlong.manager.workflow.model.instance.TaskInstance;
-import org.apache.inlong.manager.workflow.model.view.EventLogQuery;
-import org.apache.inlong.manager.workflow.model.view.ProcessDetail;
-import org.apache.inlong.manager.workflow.model.view.ProcessListView;
-import org.apache.inlong.manager.workflow.model.view.ProcessQuery;
-import org.apache.inlong.manager.workflow.model.view.ProcessSummaryQuery;
-import org.apache.inlong.manager.workflow.model.view.ProcessSummaryView;
-import org.apache.inlong.manager.workflow.model.view.TaskListView;
-import org.apache.inlong.manager.workflow.model.view.TaskQuery;
-import org.apache.inlong.manager.workflow.model.view.TaskSummaryQuery;
-import org.apache.inlong.manager.workflow.model.view.TaskSummaryView;
+import org.apache.inlong.manager.common.workflow.QueryService;
+import org.apache.inlong.manager.common.workflow.WorkflowEngine;
+import org.apache.inlong.manager.common.exceptions.WorkflowNoRollbackException;
+import org.apache.inlong.manager.common.model.TaskState;
+import org.apache.inlong.manager.common.model.definition.Process;
+import org.apache.inlong.manager.common.model.definition.ProcessForm;
+import org.apache.inlong.manager.common.model.definition.TaskForm;
+import org.apache.inlong.manager.common.model.definition.UserTask;
+import org.apache.inlong.manager.common.model.instance.ProcessInstance;
+import org.apache.inlong.manager.common.model.instance.TaskInstance;
+import org.apache.inlong.manager.common.model.view.EventLogQuery;
+import org.apache.inlong.manager.common.model.view.ProcessDetail;
+import org.apache.inlong.manager.common.model.view.ProcessListView;
+import org.apache.inlong.manager.common.model.view.ProcessQuery;
+import org.apache.inlong.manager.common.model.view.ProcessSummaryQuery;
+import org.apache.inlong.manager.common.model.view.ProcessSummaryView;
+import org.apache.inlong.manager.common.model.view.TaskListView;
+import org.apache.inlong.manager.common.model.view.TaskQuery;
+import org.apache.inlong.manager.common.model.view.TaskSummaryQuery;
+import org.apache.inlong.manager.common.model.view.TaskSummaryView;
 import org.apache.inlong.manager.workflow.util.WorkflowFormParserUtils;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
@@ -64,6 +65,7 @@ import org.springframework.util.CollectionUtils;
 @Service
 public class WorkflowServiceImpl implements WorkflowService {
 
+    @Getter
     private WorkflowEngine workflowEngine;
 
     @Autowired
