@@ -33,15 +33,15 @@ import org.apache.inlong.manager.service.workflow.WorkflowService;
 import org.apache.inlong.manager.service.workflow.WorkflowTaskExecuteLog;
 import org.apache.inlong.manager.service.workflow.WorkflowTaskExecuteLogQuery;
 import org.apache.inlong.manager.service.workflow.WorkflowTaskOperation;
-import org.apache.inlong.manager.workflow.model.view.ProcessDetail;
-import org.apache.inlong.manager.workflow.model.view.ProcessListView;
-import org.apache.inlong.manager.workflow.model.view.ProcessQuery;
-import org.apache.inlong.manager.workflow.model.view.ProcessSummaryQuery;
-import org.apache.inlong.manager.workflow.model.view.ProcessSummaryView;
-import org.apache.inlong.manager.workflow.model.view.TaskListView;
-import org.apache.inlong.manager.workflow.model.view.TaskQuery;
-import org.apache.inlong.manager.workflow.model.view.TaskSummaryQuery;
-import org.apache.inlong.manager.workflow.model.view.TaskSummaryView;
+import org.apache.inlong.manager.common.model.view.ProcessDetail;
+import org.apache.inlong.manager.common.model.view.ProcessListView;
+import org.apache.inlong.manager.common.model.view.ProcessQuery;
+import org.apache.inlong.manager.common.model.view.ProcessSummaryQuery;
+import org.apache.inlong.manager.common.model.view.ProcessSummaryView;
+import org.apache.inlong.manager.common.model.view.TaskListView;
+import org.apache.inlong.manager.common.model.view.TaskQuery;
+import org.apache.inlong.manager.common.model.view.TaskSummaryQuery;
+import org.apache.inlong.manager.common.model.view.TaskSummaryView;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.PathVariable;
