@@ -20,10 +20,10 @@ package org.apache.inlong.manager.service.workflow;
 import com.github.pagehelper.PageInfo;
 import java.util.Collections;
 import org.apache.inlong.manager.web.ServiceBaseTest;
-import org.apache.inlong.manager.workflow.core.WorkflowDataAccessor;
-import org.apache.inlong.manager.workflow.model.ProcessState;
-import org.apache.inlong.manager.workflow.model.instance.ProcessInstance;
-import org.apache.inlong.manager.workflow.model.instance.TaskInstance;
+import org.apache.inlong.manager.common.workflow.WorkflowDataAccessor;
+import org.apache.inlong.manager.common.model.ProcessState;
+import org.apache.inlong.manager.common.model.instance.ProcessInstance;
+import org.apache.inlong.manager.common.model.instance.TaskInstance;
 import org.junit.Assert;
 import org.junit.Test;
 import org.springframework.beans.factory.annotation.Autowired;
