@@ -21,23 +21,23 @@ import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Lists;
 import java.util.List;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.inlong.manager.workflow.core.TransactionHelper;
-import org.apache.inlong.manager.workflow.core.WorkflowDataAccessor;
-import org.apache.inlong.manager.workflow.core.WorkflowProcessorExecutor;
+import org.apache.inlong.manager.common.workflow.TransactionHelper;
+import org.apache.inlong.manager.common.workflow.WorkflowDataAccessor;
+import org.apache.inlong.manager.common.workflow.WorkflowProcessorExecutor;
 import org.apache.inlong.manager.workflow.core.processor.EndEventProcessor;
 import org.apache.inlong.manager.workflow.core.processor.ServiceTaskProcessor;
 import org.apache.inlong.manager.workflow.core.processor.SkipAbleElementProcessor;
 import org.apache.inlong.manager.workflow.core.processor.StartEventProcessor;
 import org.apache.inlong.manager.workflow.core.processor.UserTaskProcessor;
 import org.apache.inlong.manager.workflow.core.processor.WorkflowElementProcessor;
-import org.apache.inlong.manager.workflow.exception.WorkflowException;
-import org.apache.inlong.manager.workflow.exception.WorkflowNoRollbackException;
-import org.apache.inlong.manager.workflow.exception.WorkflowRollbackOnceException;
-import org.apache.inlong.manager.workflow.model.WorkflowContext;
-import org.apache.inlong.manager.workflow.model.definition.Element;
-import org.apache.inlong.manager.workflow.model.definition.NextableElement;
-import org.apache.inlong.manager.workflow.model.definition.SkippableElement;
-import org.apache.inlong.manager.workflow.model.definition.Task;
+import org.apache.inlong.manager.common.exceptions.WorkflowException;
+import org.apache.inlong.manager.common.exceptions.WorkflowNoRollbackException;
+import org.apache.inlong.manager.common.exceptions.WorkflowRollbackOnceException;
+import org.apache.inlong.manager.common.model.WorkflowContext;
+import org.apache.inlong.manager.common.model.definition.Element;
+import org.apache.inlong.manager.common.model.definition.NextableElement;
+import org.apache.inlong.manager.common.model.definition.SkippableElement;
+import org.apache.inlong.manager.common.model.definition.Task;
 import org.springframework.transaction.TransactionDefinition;
 import org.springframework.transaction.support.TransactionCallback;
 
