@@ -34,8 +34,18 @@ public class Constants {
 
     public static final String SINK_TYPE_HIVE = "hive";
 
+    public static final String SINK_TYPE_ICEBERG = "iceberg";
+
+    public static final String SINK_TYPE_KAFKA = "kafka";
+
     public static final String METRIC_DATA_OUTPUT_TAG_ID = "metric_data_side_output";
 
+    public static final int METRIC_AUDIT_ID_FOR_INPUT = 7;
+
+    public static final int METRIC_AUDIT_ID_FOR_OUTPUT = 8;
+
+    public static final String INLONG_GROUP_ID = "inlong.group.id";
+
     // ------------------------------------------------------------------------
     //  Operator uid
     // ------------------------------------------------------------------------
@@ -189,6 +199,13 @@ public class Constants {
             key("zookeeper.sasl.disable")
                     .defaultValue(false);
 
+    // ------------------------------------------------------------------------
+    //  Kafka sink related configs
+    // ------------------------------------------------------------------------
+    public static final ConfigOption<Integer> SINK_KAFKA_PRODUCER_POOL_SIZE =
+            key("sink.kafka.producer.pool.size")
+                    .defaultValue(5);
+
     // ------------------------------------------------------------------------
     //  Hive sink related configs
     // ------------------------------------------------------------------------
@@ -282,4 +299,18 @@ public class Constants {
         key("metrics.aggregator.window.size")
             .defaultValue(5)
             .withDescription("minutes");
+
+    public static final ConfigOption<String> METRICS_AUDIT_PROXY_HOSTS =
+            key("metrics.audit.proxy.hosts")
+                    .noDefaultValue()
+                    .withDescription("Audit proxy host address for reporting audit metrics. "
+                            + "e.g. 127.0.0.1:10081,0.0.0.1:10081");
+
+    // ------------------------------------------------------------------------
+    //  Single tenant related
+    // ------------------------------------------------------------------------
+    public static final ConfigOption<String> DATAFLOW_INFO_FILE =
+            key("dataflow.info.file")
+                    .noDefaultValue()
+                    .withDescription("The file which contains dataflow info for a single tenant job");
 }
