@@ -28,18 +28,18 @@ import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.inlong.sort.configuration.Configuration;
 import org.apache.inlong.sort.configuration.Constants;
-import org.apache.inlong.sort.flink.clickhouse.ClickHouseMultiSinkFunction;
+import org.apache.inlong.sort.flink.multitenant.clickhouse.ClickHouseMultiSinkFunction;
 import org.apache.inlong.sort.flink.deserialization.DeserializationSchema;
-import org.apache.inlong.sort.flink.doris.DorisMultiSinkFunction;
-import org.apache.inlong.sort.flink.hive.HiveMultiTenantCommitter;
-import org.apache.inlong.sort.flink.hive.HiveMultiTenantWriter;
+import org.apache.inlong.sort.flink.multitenant.doris.DorisMultiSinkFunction;
+import org.apache.inlong.sort.flink.multitenant.hive.HiveMultiTenantCommitter;
+import org.apache.inlong.sort.flink.multitenant.hive.HiveMultiTenantWriter;
 import org.apache.inlong.sort.flink.metrics.MetricData;
 import org.apache.inlong.sort.flink.metrics.MetricsAggregator.MetricsAggregateFunction;
 import org.apache.inlong.sort.flink.metrics.MetricsAggregator.MetricsProcessWindowFunction;
 import org.apache.inlong.sort.flink.metrics.MetricsAssignerWithPeriodicWatermarks;
 import org.apache.inlong.sort.flink.metrics.MetricsLogSink;
-import org.apache.inlong.sort.flink.pulsar.MultiTopicPulsarSourceFunction;
-import org.apache.inlong.sort.flink.tubemq.MultiTopicTubeSourceFunction;
+import org.apache.inlong.sort.flink.multitenant.pulsar.MultiTopicPulsarSourceFunction;
+import org.apache.inlong.sort.flink.multitenant.tubemq.MultiTopicTubeSourceFunction;
 import org.apache.inlong.sort.util.ParameterTool;
 import org.apache.flink.streaming.api.windowing.assigners.TumblingEventTimeWindows;
 import org.apache.flink.streaming.api.windowing.time.Time;
