@@ -18,13 +18,19 @@
 package org.apache.inlong.sort.flink.deserialization;
 
 import com.google.common.base.Preconditions;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Map;
+import org.apache.commons.lang3.tuple.Pair;
 import org.apache.flink.streaming.api.functions.ProcessFunction;
 import org.apache.flink.util.Collector;
+import org.apache.inlong.audit.AuditImp;
 import org.apache.inlong.sort.configuration.Configuration;
 import org.apache.inlong.sort.configuration.Constants;
 import org.apache.inlong.sort.flink.Record;
 import org.apache.inlong.sort.flink.SerializedRecord;
-import org.apache.inlong.sort.flink.TDMsgMixedSerializedRecord;
+import org.apache.inlong.sort.flink.InLongMsgMixedSerializedRecord;
 import org.apache.inlong.sort.flink.metrics.MetricData;
 import org.apache.inlong.sort.flink.metrics.MetricData.MetricSource;
 import org.apache.inlong.sort.flink.metrics.MetricData.MetricType;
@@ -34,6 +40,7 @@ import org.apache.inlong.sort.meta.MetaManager;
 import org.apache.inlong.sort.meta.MetaManager.DataFlowInfoListener;
 import org.apache.inlong.sort.protocol.DataFlowInfo;
 import org.apache.flink.util.OutputTag;
+import org.apache.inlong.sort.util.CommonUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -54,7 +61,7 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
 
     private transient Object schemaLock;
 
-    private transient MultiTenancyTDMsgMixedDeserializer multiTenancyTdMsgMixedDeserializer;
+    private transient MultiTenancyInLongMsgMixedDeserializer multiTenancyInLongMsgMixedDeserializer;
 
     private transient MultiTenancyDeserializer multiTenancyDeserializer;
 
@@ -62,6 +69,11 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
 
     private transient Boolean enableOutputMetrics;
 
+    // dataflow id -> Pair<group id, stream id>
+    private transient Map<Long, Pair<String, String>> inLongGroupIdAndStreamIdMap;
+
+    private transient AuditImp auditImp;
+
     public DeserializationSchema(Configuration config) {
         this.config = Preconditions.checkNotNull(config);
     }
@@ -69,13 +81,22 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
     @Override
     public void open(org.apache.flink.configuration.Configuration parameters) throws Exception {
         schemaLock = new Object();
-        multiTenancyTdMsgMixedDeserializer = new MultiTenancyTDMsgMixedDeserializer();
+        multiTenancyInLongMsgMixedDeserializer = new MultiTenancyInLongMsgMixedDeserializer();
         multiTenancyDeserializer = new MultiTenancyDeserializer();
         fieldMappingTransformer = new FieldMappingTransformer();
+        inLongGroupIdAndStreamIdMap = new HashMap<>();
+
         recordTransformer = new RecordTransformer(config.getInteger(Constants.ETL_RECORD_SERIALIZATION_BUFFER_SIZE));
         metaManager = MetaManager.getInstance(config);
         metaManager.registerDataFlowInfoListener(new DataFlowInfoListenerImpl());
         enableOutputMetrics = config.getBoolean(Constants.METRICS_ENABLE_OUTPUT);
+
+        String auditHostAndPorts = config.getString(Constants.METRICS_AUDIT_PROXY_HOSTS);
+        if (auditHostAndPorts != null) {
+            AuditImp.getInstance().setAuditProxy(new HashSet<>(Arrays.asList(auditHostAndPorts.split(","))));
+            auditImp = AuditImp.getInstance();
+            LOG.info("audit proxy address: " + auditHostAndPorts);
+        }
     }
 
     @Override
@@ -84,6 +105,10 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
             metaManager.close();
             metaManager = null;
         }
+
+        if (auditImp != null) {
+            auditImp.sendReport();
+        }
     }
 
     @Override
@@ -122,13 +147,30 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
                     context.output(METRIC_DATA_OUTPUT_TAG, metricData);
                 }
 
-                collector.collect(recordTransformer.toSerializedRecord(sinkRecord));
+                SerializedRecord serializedSinkRecord = recordTransformer.toSerializedRecord(sinkRecord);
+
+                if (auditImp != null) {
+                    Pair<String, String> groupIdAndStreamId = inLongGroupIdAndStreamIdMap.getOrDefault(
+                            serializedRecord.getDataFlowId(),
+                            Pair.of("", ""));
+
+                    auditImp.add(
+                            Constants.METRIC_AUDIT_ID_FOR_INPUT,
+                            groupIdAndStreamId.getLeft(),
+                            groupIdAndStreamId.getRight(),
+                            sinkRecord.getTimestampMillis(),
+                            1,
+                            serializedSinkRecord.getData().length);
+                }
+
+                collector.collect(serializedSinkRecord);
             });
 
-            if (serializedRecord instanceof TDMsgMixedSerializedRecord) {
-                final TDMsgMixedSerializedRecord tdmsgRecord = (TDMsgMixedSerializedRecord) serializedRecord;
+            if (serializedRecord instanceof InLongMsgMixedSerializedRecord) {
+                final InLongMsgMixedSerializedRecord
+                        inlongmsgRecord = (InLongMsgMixedSerializedRecord) serializedRecord;
                 synchronized (schemaLock) {
-                    multiTenancyTdMsgMixedDeserializer.deserialize(tdmsgRecord, transformCollector);
+                    multiTenancyInLongMsgMixedDeserializer.deserialize(inlongmsgRecord, transformCollector);
                 }
             } else {
                 synchronized (schemaLock) {
@@ -157,30 +199,40 @@ public class DeserializationSchema extends ProcessFunction<SerializedRecord, Ser
         @Override
         public void addDataFlow(DataFlowInfo dataFlowInfo) throws Exception {
             synchronized (schemaLock) {
-                multiTenancyTdMsgMixedDeserializer.addDataFlow(dataFlowInfo);
+                multiTenancyInLongMsgMixedDeserializer.addDataFlow(dataFlowInfo);
                 multiTenancyDeserializer.addDataFlow(dataFlowInfo);
                 fieldMappingTransformer.addDataFlow(dataFlowInfo);
                 recordTransformer.addDataFlow(dataFlowInfo);
+
+                inLongGroupIdAndStreamIdMap.put(
+                        dataFlowInfo.getId(),
+                        CommonUtils.getInLongGroupIdAndStreamId(dataFlowInfo));
             }
         }
 
         @Override
         public void updateDataFlow(DataFlowInfo dataFlowInfo) throws Exception {
             synchronized (schemaLock) {
-                multiTenancyTdMsgMixedDeserializer.updateDataFlow(dataFlowInfo);
+                multiTenancyInLongMsgMixedDeserializer.updateDataFlow(dataFlowInfo);
                 multiTenancyDeserializer.updateDataFlow(dataFlowInfo);
                 fieldMappingTransformer.updateDataFlow(dataFlowInfo);
                 recordTransformer.updateDataFlow(dataFlowInfo);
+
+                inLongGroupIdAndStreamIdMap.put(
+                        dataFlowInfo.getId(),
+                        CommonUtils.getInLongGroupIdAndStreamId(dataFlowInfo));
             }
         }
 
         @Override
         public void removeDataFlow(DataFlowInfo dataFlowInfo) throws Exception {
             synchronized (schemaLock) {
-                multiTenancyTdMsgMixedDeserializer.removeDataFlow(dataFlowInfo);
+                multiTenancyInLongMsgMixedDeserializer.removeDataFlow(dataFlowInfo);
                 multiTenancyDeserializer.removeDataFlow(dataFlowInfo);
                 fieldMappingTransformer.removeDataFlow(dataFlowInfo);
                 recordTransformer.removeDataFlow(dataFlowInfo);
+
+                inLongGroupIdAndStreamIdMap.remove(dataFlowInfo.getId());
             }
         }
     }
