@@ -249,21 +249,21 @@ func (c *consumer) GetMessage() (*ConsumerResult, error) {
 		}
 		return nil, err
 	}
-	cs := &ConsumerResult{
+	cr := &ConsumerResult{
 		TopicName:      partition.GetTopic(),
 		ConfirmContext: confirmContext,
 		PeerInfo:       pi,
 	}
 	msgs, err := c.processGetMessageRspB2C(pi, isFiltered, partition, confirmContext, rsp)
 	if err != nil {
-		return cs, err
+		return cr, err
 	}
-	cs.Messages = msgs
-	return cs, err
+	cr.Messages = msgs
+	return cr, err
 }
 
 // Confirm implementation of TubeMQ consumer.
-func (c *consumer) Confirm(confirmContext string, consumed bool) (*ConsumerResult, error) {
+func (c *consumer) Confirm(confirmContext string, consumed bool) (*ConfirmResult, error) {
 	partitionKey, bookedTime, err := util.ParseConfirmContext(confirmContext)
 	if err != nil {
 		return nil, errs.New(errs.RetBadRequest, "illegel confirm_context content: unregular confirm_context value format")
@@ -280,7 +280,8 @@ func (c *consumer) Confirm(confirmContext string, consumed bool) (*ConsumerResul
 		return nil, errs.New(errs.RetErrConfirmTimeout, "Not found the partition by confirm_context!")
 	}
 
-	rsp, err := c.sendConfirmReq2Broker(partition)
+	defer c.rmtDataCache.ReleasePartition(true, c.subInfo.IsFiltered(topic), confirmContext, consumed)
+	rsp, err := c.sendConfirmReq2Broker(partition, consumed)
 	if err != nil {
 		log.Infof("[CONSUMER]Confirm error %s", err.Error())
 		return nil, err
@@ -290,22 +291,22 @@ func (c *consumer) Confirm(confirmContext string, consumed bool) (*ConsumerResul
 		BrokerHost:   partition.GetBroker().GetHost(),
 		PartitionID:  uint32(partition.GetPartitionID()),
 		PartitionKey: partition.GetPartitionKey(),
-		CurrOffset:   util.InvalidValue,
+		CurrOffset:   rsp.GetCurrOffset(),
+		MaxOffset:    rsp.GetMaxOffset(),
 	}
-	cs := &ConsumerResult{
-		TopicName: partition.GetTopic(),
-		PeerInfo:  pi,
+	cr := &ConfirmResult{
+		ConfirmContext: confirmContext,
+		TopicName:      partition.GetTopic(),
+		PeerInfo:       pi,
 	}
 	if !rsp.GetSuccess() {
-		return cs, errs.New(rsp.GetErrCode(), rsp.GetErrMsg())
+		return cr, errs.New(rsp.GetErrCode(), rsp.GetErrMsg())
 	}
-	currOffset := rsp.GetCurrOffset()
-	c.rmtDataCache.BookPartitionInfo(partitionKey, currOffset, util.InvalidValue)
-	err = c.rmtDataCache.ReleasePartition(true, c.subInfo.IsFiltered(topic), confirmContext, consumed)
-	return cs, err
+	c.rmtDataCache.BookPartitionInfo(partitionKey, rsp.GetCurrOffset(), rsp.GetMaxOffset())
+	return cr, err
 }
 
-func (c *consumer) sendConfirmReq2Broker(partition *metadata.Partition) (*protocol.CommitOffsetResponseB2C, error) {
+func (c *consumer) sendConfirmReq2Broker(partition *metadata.Partition, consumed bool) (*protocol.CommitOffsetResponseB2C, error) {
 	m := &metadata.Metadata{}
 	node := &metadata.Node{}
 	node.SetHost(util.GetLocalHost())
@@ -313,6 +314,7 @@ func (c *consumer) sendConfirmReq2Broker(partition *metadata.Partition) (*protoc
 	m.SetNode(node)
 	sub := &metadata.SubscribeInfo{}
 	sub.SetGroup(c.config.Consumer.Group)
+	partition.SetLastConsumed(consumed)
 	sub.SetPartition(partition)
 	m.SetSubscribeInfo(sub)
 
