@@ -32,13 +32,16 @@ import (
 )
 
 const (
-	MaxRPCTimeout      = 300000 * time.Millisecond
-	MinRPCTimeout      = 8000 * time.Millisecond
-	MaxSessionKeyLen   = 1024
-	MaxGroupLen        = 1024
-	MaxTopicLen        = 64
-	MaxFilterLen       = 256
-	MaxFilterItemCount = 500
+	MaxRPCTimeout              = 300000 * time.Millisecond
+	MinRPCTimeout              = 8000 * time.Millisecond
+	MaxSessionKeyLen           = 1024
+	MaxGroupLen                = 1024
+	MaxTopicLen                = 64
+	MaxFilterLen               = 256
+	MaxFilterItemCount         = 500
+	ConsumeFromFirstOffset     = -1
+	ConsumeFromLatestOffset    = 0
+	ConsumeFromMaxOffsetAlways = 1
 )
 
 // Config defines multiple configuration options.
@@ -196,6 +199,10 @@ func (c *Config) ValidateConsumer() error {
 		}
 	}
 
+	if err := c.validateConsumePosition(); err != nil {
+		return err
+	}
+
 	err := c.validateMaster()
 	if err != nil {
 		return errs.New(errs.RetInvalidConfig, err.Error())
@@ -302,6 +309,13 @@ func (c *Config) validateGroup(group string) error {
 	return nil
 }
 
+func (c *Config) validateConsumePosition() error {
+	if c.Consumer.ConsumePosition < ConsumeFromFirstOffset || c.Consumer.ConsumePosition > ConsumeFromMaxOffsetAlways {
+		return errs.New(errs.RetInvalidConfig, fmt.Sprintf("consumePosition should be only in (-1, 0, 1), while %d is passed", c.Consumer.ConsumePosition))
+	}
+	return nil
+}
+
 // ParseAddress parses the address to user-defined config.
 func ParseAddress(address string) (config *Config, err error) {
 	c := NewDefaultConfig()
@@ -545,3 +559,9 @@ func WithBoundConsume(sessionKey string, sourceCount int, selectBig bool, partOf
 		c.Consumer.PartitionOffset = partOffset
 	}
 }
+
+func WithConsumePosition(consumePosition int) Option {
+	return func(c *Config) {
+		c.Consumer.ConsumePosition = consumePosition
+	}
+}
