@@ -37,6 +37,8 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
+
+import org.apache.inlong.tubemq.client.common.ClientMetrics;
 import org.apache.inlong.tubemq.client.common.TubeClientVersion;
 import org.apache.inlong.tubemq.client.config.ConsumerConfig;
 import org.apache.inlong.tubemq.client.exception.TubeClientException;
@@ -114,6 +116,7 @@ public class BaseMessageConsumer implements MessageConsumer {
     private int rebalanceRetryTimes = 0;
     private long lastHeartbeatTime2Master = 0;
     private long lastHeartbeatTime2Broker = 0;
+    protected final ClientMetrics clientMetrics;
 
     /**
      * Construct a BaseMessageConsumer object.
@@ -140,6 +143,8 @@ public class BaseMessageConsumer implements MessageConsumer {
         } catch (Exception e) {
             throw new TubeClientException("Get consumer id failed!", e);
         }
+        this.clientMetrics =
+                new ClientMetrics(false, this.consumerId, this.consumerConfig);
         this.rmtDataCache =
                 new RmtDataCache(this.consumerConfig, null);
         this.rpcServiceFactory =
@@ -449,6 +454,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                 //
             }
         }
+        clientMetrics.printMetricInfo(true, strBuffer);
         logger.info(strBuffer
                 .append("[SHUTDOWN_CONSUMER] Partitions unregistered,  consumer :")
                 .append(this.consumerId).toString());
@@ -822,6 +828,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                                 .consumerRegisterC2B(createBrokerRegisterRequest(partition),
                                     AddressUtils.getLocalAddress(), consumerConfig.isTlsEnable());
                         if (responseB2C != null && responseB2C.getSuccess()) {
+                            clientMetrics.bookReg2Broker(false);
                             long currOffset =
                                 responseB2C.hasCurrOffset() ? responseB2C.getCurrOffset()
                                         : TBaseConstants.META_VALUE_UNDEFINED;
@@ -835,6 +842,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                                 .append(partition.toString()).toString());
                             strBuffer.delete(0, strBuffer.length());
                         } else {
+                            clientMetrics.bookReg2Broker(true);
                             if (responseB2C == null) {
                                 logger.warn(strBuffer.append("register2broker error! ")
                                     .append(retryTimesRegister2Broker).append(" register ")
@@ -1190,6 +1198,7 @@ public class BaseMessageConsumer implements MessageConsumer {
         Partition partition = taskContext.getPartition();
         String topic = partition.getTopic();
         String partitionKey = partition.getPartitionKey();
+        long startTime = System.currentTimeMillis();
         // Response from broker
         ClientBroker.GetMessageResponseB2C msgRspB2C = null;
         try {
@@ -1199,6 +1208,9 @@ public class BaseMessageConsumer implements MessageConsumer {
                                     partition, taskContext.isLastConsumed()),
                                     AddressUtils.getLocalAddress(), consumerConfig.isTlsEnable());
         } catch (Throwable ee) {
+            clientMetrics.bookFailRpcCall(
+                    System.currentTimeMillis() - startTime,
+                    TErrCodeConstants.UNSPECIFIED_ABNORMAL);
             // Process the exception
             rmtDataCache.errReqRelease(partitionKey, taskContext.getUsedToken(), false);
             taskContext.setFailProcessResult(400, strBuffer
@@ -1207,7 +1219,9 @@ public class BaseMessageConsumer implements MessageConsumer {
             strBuffer.delete(0, strBuffer.length());
             return taskContext;
         }
+        long dltTime = System.currentTimeMillis() - startTime;
         if (msgRspB2C == null) {
+            clientMetrics.bookFailRpcCall(dltTime, TErrCodeConstants.INTERNAL_SERVER_ERROR);
             rmtDataCache.errReqRelease(partitionKey, taskContext.getUsedToken(), false);
             taskContext.setFailProcessResult(500, "Get message null");
             return taskContext;
@@ -1217,6 +1231,7 @@ public class BaseMessageConsumer implements MessageConsumer {
             switch (msgRspB2C.getErrCode()) {
                 case TErrCodeConstants.SUCCESS: {
                     int msgSize = 0;
+                    int msgCount = 0;
                     // Convert the message payload data
                     List<Message> tmpMessageList =
                             DataConverterUtil.convertMessage(topic, msgRspB2C.getMessagesList());
@@ -1242,6 +1257,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                                 || !topicFilterSet.contains(message.getMsgType()))) {
                             continue;
                         }
+                        msgCount++;
                         messageList.add(message);
                         msgSize += message.getData().length;
                     }
@@ -1262,6 +1278,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                         strBuffer.append(partitionKey).append(TokenConstants.ATTR_SEP)
                             .append(taskContext.getUsedToken()).toString(), messageList, maxOffset);
                     strBuffer.delete(0, strBuffer.length());
+                    clientMetrics.bookSuccGetMsg(dltTime, msgCount, msgSize);
                     break;
                 }
                 case TErrCodeConstants.HB_NO_NODE:
@@ -1321,16 +1338,22 @@ public class BaseMessageConsumer implements MessageConsumer {
                     break;
                 }
             }
+            if (msgRspB2C.getErrCode() != TErrCodeConstants.SUCCESS) {
+                clientMetrics.bookFailRpcCall(dltTime, msgRspB2C.getErrCode());
+            }
             return taskContext;
         } catch (Throwable ee) {
+            clientMetrics.bookFailRpcCall(
+                    System.currentTimeMillis() - startTime,
+                    TErrCodeConstants.INTERNAL_SERVER_ERROR);
             logger.error("Process response code error", ee);
             rmtDataCache.succRspRelease(partitionKey, topic,
                     taskContext.getUsedToken(), false, isFilterConsume(topic),
                     TBaseConstants.META_VALUE_UNDEFINED, TBaseConstants.META_VALUE_UNDEFINED);
-            taskContext.setFailProcessResult(500, strBuffer
-                    .append("Get message failed,topic=")
-                    .append(topic).append(",partition=").append(partition)
-                    .append(", throw info is ").append(ee.toString()).toString());
+            taskContext.setFailProcessResult(TErrCodeConstants.INTERNAL_SERVER_ERROR,
+                    strBuffer.append("Get message failed,topic=")
+                            .append(topic).append(",partition=").append(partition)
+                            .append(", throw info is ").append(ee.toString()).toString());
             strBuffer.delete(0, strBuffer.length());
         }
         return taskContext;
@@ -1398,6 +1421,8 @@ public class BaseMessageConsumer implements MessageConsumer {
             try {
                 rmtDataCache.resumeTimeoutConsumePartitions(isPullConsume,
                         consumerConfig.getPullProtectConfirmTimeoutMs());
+                // print metric information
+                clientMetrics.printMetricInfo(false, strBuffer);
                 // Fetch the rebalance result, construct message adn return it.
                 ConsumerEvent event = rebalanceResults.poll();
                 List<SubscribeInfo> subInfoList = null;
@@ -1417,6 +1442,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                                 AddressUtils.getLocalAddress(), consumerConfig.isTlsEnable());
                 // Process unsuccessful response
                 if (response == null) {
+                    clientMetrics.bookHB2MasterTimeout();
                     logger.error(strBuffer.append("[Heartbeat Failed] ")
                             .append("return result is null!").toString());
                     heartbeatRetryTimes++;
@@ -1425,6 +1451,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                 if (!response.getSuccess()) {
                     // If master replies that cannot find current consumer node, re-register
                     if (response.getErrCode() == TErrCodeConstants.HB_NO_NODE) {
+                        clientMetrics.bookHB2MasterTimeout();
                         try {
                             ClientMaster.RegisterResponseM2C regResponse =
                                 masterService.consumerRegisterC2M(createMasterRegisterRequest(),
@@ -1466,6 +1493,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                         }
                         return;
                     }
+                    clientMetrics.bookHB2MasterException();
                     logger.error(strBuffer.append("[Heartbeat Failed] ")
                             .append(response.getErrMsg()).toString());
                     if (response.getErrCode() == TErrCodeConstants.CERTIFICATE_FAILURE) {
@@ -1618,6 +1646,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                                     }
                                 }
                                 if (heartBeatResponseV2 != null) {
+                                    clientMetrics.bookHB2BrokerException();
                                     if (heartBeatResponseV2.getErrCode()
                                         == TErrCodeConstants.CERTIFICATE_FAILURE) {
                                         for (Partition partition : partitions) {
@@ -1636,6 +1665,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                             // If there's error in the heartbeat, collect the log and print out.
                             // Release the log string buffer.
                             if (!isShutdown()) {
+                                clientMetrics.bookHB2BrokerException();
                                 samplePrintCtrl.printExceptionCaught(ee);
                                 if (!partStrSet.isEmpty()) {
                                     strBuffer.delete(0, strBuffer.length());
@@ -1655,6 +1685,7 @@ public class BaseMessageConsumer implements MessageConsumer {
                     lastHeartbeatTime2Broker = System.currentTimeMillis();
                     Thread.sleep(consumerConfig.getHeartbeatPeriodMs());
                 } catch (Throwable e) {
+                    clientMetrics.bookHB2BrokerException();
                     lastHeartbeatTime2Broker = System.currentTimeMillis();
                     if (!isShutdown()) {
                         logger.error("heartbeat thread error 3 : ", e);
