@@ -18,6 +18,7 @@
 package org.apache.inlong.tubemq.server.broker;
 
 import java.io.IOException;
+import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashSet;
@@ -49,6 +50,7 @@ import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.corebase.utils.AddressUtils;
 import org.apache.inlong.tubemq.corebase.utils.CheckSum;
 import org.apache.inlong.tubemq.corebase.utils.DataConverterUtil;
+import org.apache.inlong.tubemq.corebase.utils.DateTimeConvertUtils;
 import org.apache.inlong.tubemq.corebase.utils.ServiceStatusHolder;
 import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
 import org.apache.inlong.tubemq.corerpc.RpcConfig;
@@ -63,6 +65,7 @@ import org.apache.inlong.tubemq.server.broker.msgstore.MessageStore;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStoreManager;
 import org.apache.inlong.tubemq.server.broker.msgstore.disk.GetMessageResult;
 import org.apache.inlong.tubemq.server.broker.nodeinfo.ConsumerNodeInfo;
+import org.apache.inlong.tubemq.server.broker.offset.OffsetRecordInfo;
 import org.apache.inlong.tubemq.server.broker.offset.OffsetService;
 import org.apache.inlong.tubemq.server.broker.stats.CountService;
 import org.apache.inlong.tubemq.server.broker.stats.GroupCountService;
@@ -82,7 +85,7 @@ import org.apache.inlong.tubemq.server.common.utils.RowLock;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-/***
+/**
  * Broker service. Receive and conduct client's request, store messages, query messages, print statistics, etc.
  */
 public class BrokerServiceServer implements BrokerReadService, BrokerWriteService, Server {
@@ -134,7 +137,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                 this.tubeConfig.getConsumerRegTimeoutMs(), consumerListener);
     }
 
-    /***
+    /**
      * Start broker service
      *
      * @throws Exception
@@ -209,7 +212,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         this.started.set(true);
     }
 
-    /***
+    /**
      * Stop broker service.
      */
     @Override
@@ -223,26 +226,26 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         logger.info("BrokerService server stopped");
     }
 
-    /***
+    /**
      * Get broker's registered consumer info
      *
-     * @return
+     * @return query result
      */
     public Map<String, ConsumerNodeInfo> getConsumerRegisterMap() {
         return consumerRegisterMap;
     }
 
-    /***
+    /**
      * Get consumer's info by store key.
      *
-     * @param storeKey
-     * @return
+     * @param storeKey   the query key
+     * @return           the consumer nodeinfo object
      */
     public ConsumerNodeInfo getConsumerNodeInfo(String storeKey) {
         return consumerRegisterMap.get(storeKey);
     }
 
-    /***
+    /**
      * Get consumer's register time.
      *
      * @param consumerId
@@ -259,14 +262,14 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         return (timeoutInfo.getTimeoutTime() - heartbeatManager.getConsumerTimeoutDlt());
     }
 
-    /***
+    /**
      * Handle consumer's getMessageRequest.
      *
-     * @param request
-     * @param rmtAddress
-     * @param overtls
-     * @return
-     * @throws Throwable
+     * @param request        the http request
+     * @param rmtAddress     the remote node address
+     * @param overtls        whether over TLS
+     * @return               the response message
+     * @throws Throwable     the exception during processing
      */
     @Override
     public GetMessageResponseB2C getMessagesC2B(GetMessageRequestC2B request,
@@ -413,23 +416,23 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
      * Query offset, then read data.
      *
-     * @param msgStore
-     * @param consumerNodeInfo
-     * @param group
-     * @param topic
-     * @param partitionId
-     * @param lastConsumed
-     * @param isManualCommitOffset
-     * @param sentAddr
-     * @param brokerAddr
-     * @param rmtAddrInfo
-     * @param isEscFlowCtrl
-     * @param sb
-     * @return
-     * @throws IOException
+     * @param msgStore                the message store instance
+     * @param consumerNodeInfo        the consumer node instance
+     * @param group                   the consume group name
+     * @param topic                   the topic name
+     * @param partitionId             the partition id
+     * @param lastConsumed            whether the last messages has been consumed
+     * @param isManualCommitOffset    whether manual commit offset
+     * @param sentAddr                the remote ip
+     * @param brokerAddr              the broker ip
+     * @param rmtAddrInfo             the remote address
+     * @param isEscFlowCtrl           whether escape flow control
+     * @param sb                      the string buffer
+     * @return    the query result
+     * @throws IOException the exception during processing
      */
     private GetMessageResult getMessages(final MessageStore msgStore,
                                          final ConsumerNodeInfo consumerNodeInfo,
@@ -466,7 +469,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
             sb.delete(0, sb.length());
             GetMessageResult msgQueryResult =
                     msgStore.getMessages(reqSwitch, requestOffset,
-                            partitionId, consumerNodeInfo, baseKey, msgDataSizeLimit);
+                            partitionId, consumerNodeInfo, baseKey, msgDataSizeLimit, 0);
             offsetManager.bookOffset(group, topic, partitionId,
                     msgQueryResult.lastReadOffset, isManualCommitOffset,
                     msgQueryResult.transferedMessageList.isEmpty(), sb);
@@ -484,16 +487,16 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
      * Get message snapshot by given parameters.
      *
-     * @param topicName
-     * @param partitionId
-     * @param msgCount
-     * @param filterCondSet
-     * @param sb
-     * @return
-     * @throws Exception
+     * @param topicName        the topic name
+     * @param partitionId      the partition id
+     * @param msgCount         the message count need to query
+     * @param filterCondSet    the filter condition set
+     * @param sb               the string buffer
+     * @return                 the messages returned
+     * @throws Exception       the exception during processing
      */
     public StringBuilder getMessageSnapshot(String topicName, int partitionId,
                                             int msgCount, final Set<String> filterCondSet,
@@ -550,7 +553,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                 List<String> transferMessageList = new ArrayList<>();
                 List<TransferedMessage> tmpMsgList = getMessageResult.transferedMessageList;
                 List<Message> messageList = DataConverterUtil.convertMessage(topicName, tmpMsgList);
-                int startPos = messageList.size() - msgCount < 0 ? 0 : messageList.size() - msgCount;
+                int startPos = Math.max(messageList.size() - msgCount, 0);
                 for (; startPos < messageList.size(); startPos++) {
                     String msgItem = new String(
                             Base64.encodeBase64(messageList.get(startPos).getData()));
@@ -575,14 +578,14 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
      * Handle producer's sendMessage request.
      *
-     * @param request
-     * @param rmtAddress
-     * @param overtls
-     * @return
-     * @throws Throwable
+     * @param request       the request
+     * @param rmtAddress    the remote ip
+     * @param overtls       whether transfer over TLS
+     * @return              the response
+     * @throws Throwable    the exception during processing
      */
     @Override
     public SendMessageResponseB2P sendMessageP2B(SendMessageRequestP2B request,
@@ -615,7 +618,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         final String producerId = (String) result.getRetData();
         // get and check topicName and partitionId field
         final int partitionId = request.getPartitionId();
-        if (!PBParameterUtils.getTopicNamePartIdInfo(request.getTopicName(),
+        if (!PBParameterUtils.getTopicNamePartIdInfo(true, request.getTopicName(),
                 partitionId, this.metadataManager, strBuffer, result)) {
             builder.setErrCode(result.getErrCode());
             builder.setErrMsg(result.getErrMsg());
@@ -701,14 +704,99 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
+     * append group current offset to storage
+     *
+     * @param groupOffsetMap group offset information
+     * @param brokerAddrId broker Address id
+     * @param storeTime store time
+     * @param retryCnt  retry count
+     * @param waitRetryMs  wait duration on overflow
+     * @param strBuff    string buffer
+     */
+    public void appendGroupOffsetInfo(Map<String, OffsetRecordInfo> groupOffsetMap,
+                                      int brokerAddrId, long storeTime, int retryCnt,
+                                      long waitRetryMs, StringBuilder strBuff) {
+        if (groupOffsetMap == null || groupOffsetMap.isEmpty()) {
+            return;
+        }
+        int checkSum;
+        int msgTypeCode;
+        int partitionId;
+        byte[] dataValue;
+        byte[] attrData;
+        ByteBuffer rcdBuff;
+        byte[] msgData;
+        int msgLength;
+        int msgFlag = 1;
+        String baseKey;
+        MessageStore msgStore;
+        AppendResult appendResult = new AppendResult();
+        // get store time
+        String sendTime = DateTimeConvertUtils.ms2yyyyMMddHHmm(storeTime);
+        for (Map.Entry<String, OffsetRecordInfo> entry : groupOffsetMap.entrySet()) {
+            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
+                continue;
+            }
+            // build record info;
+            msgTypeCode = entry.getKey().hashCode();
+            partitionId = Math.abs(msgTypeCode) % TServerConstants.OFFSET_HISTORY_NUMPARTS;
+            // get msg data
+            entry.getValue().buildRecordInfo(strBuff, storeTime);
+            dataValue = StringUtils.getBytesUtf8(strBuff.toString());
+            strBuff.delete(0, strBuff.length());
+            // get msg attributes
+            strBuff.append(TokenConstants.TOKEN_MSG_TYPE)
+                    .append(TokenConstants.EQ).append(msgTypeCode)
+                    .append(TokenConstants.ARRAY_SEP)
+                    .append(TokenConstants.TOKEN_MSG_TIME)
+                    .append(TokenConstants.EQ).append(sendTime)
+                    .append(TokenConstants.ARRAY_SEP)
+                    .append(TServerConstants.TOKEN_OFFSET_GROUP)
+                    .append(TokenConstants.EQ).append(entry.getKey());
+            attrData = StringUtils.getBytesUtf8(strBuff.toString());
+            strBuff.delete(0, strBuff.length());
+            // build binary record
+            rcdBuff = ByteBuffer.allocate(4 + attrData.length + dataValue.length);
+            rcdBuff.putInt(attrData.length);
+            rcdBuff.put(attrData);
+            rcdBuff.put(dataValue);
+            msgData = rcdBuff.array();
+            // get msg length and check-sum
+            msgLength = msgData.length;
+            checkSum = CheckSum.crc32(msgData);
+            // store record
+            try {
+                msgStore = storeManager.getOrCreateMessageStore(
+                        TServerConstants.OFFSET_HISTORY_NAME, partitionId);
+                if (msgStore.appendMsg2(appendResult, msgLength, checkSum, msgData,
+                        msgTypeCode, msgFlag, partitionId, brokerAddrId, storeTime,
+                        retryCnt, waitRetryMs)) {
+                    baseKey = strBuff.append(TServerConstants.OFFSET_HISTORY_NAME)
+                            .append("#").append(tubeConfig.getHostName())
+                            .append("#").append(tubeConfig.getHostName())
+                            .append("#").append(partitionId)
+                            .append("#").append(sendTime).toString();
+                    putCounterGroup.add(baseKey, 1L, msgLength);
+                    strBuff.delete(0, strBuff.length());
+                } else {
+                    logger.warn("Put history offset overflow !");
+                }
+            } catch (Throwable ex) {
+                strBuff.delete(0, strBuff.length());
+                logger.error("Put history offset failed ", ex);
+            }
+        }
+    }
+
+    /**
      * Handle consumer register request.
      *
-     * @param request
-     * @param rmtAddress
-     * @param overtls
-     * @return
-     * @throws Throwable
+     * @param request       the request
+     * @param rmtAddress    the remote address
+     * @param overtls       whether transfer over TLS
+     * @return              the response
+     * @throws Throwable    the exception during processing
      */
     @Override
     public RegisterResponseB2C consumerRegisterC2B(RegisterRequestC2B request,
@@ -811,19 +899,19 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
      * Handle consumer's register request.
      *
-     * @param clientId
-     * @param groupName
-     * @param topicName
-     * @param partStr
-     * @param filterCondSet
-     * @param overtls
-     * @param request
-     * @param builder
-     * @param strBuffer
-     * @return
+     * @param clientId        the client id
+     * @param groupName       the group name
+     * @param topicName       the topic name
+     * @param partStr         the group-topic-partitionId key
+     * @param filterCondSet   the filter condition set
+     * @param overtls      whether transfer over TLS
+     * @param request         the request
+     * @param builder      the response builder
+     * @param strBuffer    the string buffer
+     * @return             the response
      */
     private RegisterResponseB2C inProcessConsumerRegister(final String clientId, final String groupName,
                                                           final String topicName, final String partStr,
@@ -907,18 +995,18 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         }
     }
 
-    /***
+    /**
      * Handle consumer's unregister request.
      *
-     * @param clientId
-     * @param groupName
-     * @param topicName
-     * @param partStr
-     * @param request
-     * @param overtls
-     * @param builder
-     * @param strBuffer
-     * @return
+     * @param clientId     the client id
+     * @param groupName    the group name
+     * @param topicName    the topic name
+     * @param partStr      the group-topic-partitionId key
+     * @param request      the request
+     * @param overtls      whether transfer over TLS
+     * @param builder      the response builder
+     * @param strBuffer    the string buffer
+     * @return             the response
      */
     private RegisterResponseB2C inProcessConsumerUnregister(final String clientId, final String groupName,
                                                             final String topicName, final String partStr,
@@ -976,14 +1064,14 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         return builder.build();
     }
 
-    /***
+    /**
      * Handle consumer's heartbeat request.
      *
-     * @param request
-     * @param rmtAddress
-     * @param overtls
-     * @return
-     * @throws Throwable
+     * @param request        the request
+     * @param rmtAddress     the remote address
+     * @param overtls        whether transfer over TLS
+     * @return               the response
+     * @throws Throwable     the exception during processing
      */
     @Override
     public HeartBeatResponseB2C consumerHeartbeatC2B(HeartBeatRequestC2B request,
@@ -1097,14 +1185,14 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         return builder.build();
     }
 
-    /***
+    /**
      * Handle consumer's commit offset request.
      *
-     * @param request
-     * @param rmtAddress
-     * @param overtls
-     * @return
-     * @throws Throwable
+     * @param request        the request
+     * @param rmtAddress     the remote address
+     * @param overtls        whether transfer over TLS
+     * @return               the response
+     * @throws Throwable     the exception during processing
      */
     @Override
     public CommitOffsetResponseB2C consumerCommitC2B(CommitOffsetRequestC2B request,
@@ -1138,7 +1226,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         final String groupName = (String) result.getRetData();
         int partitionId = request.getPartitionId();
         // get and check topicName and partitionId field
-        if (!PBParameterUtils.getTopicNamePartIdInfo(request.getTopicName(),
+        if (!PBParameterUtils.getTopicNamePartIdInfo(false, request.getTopicName(),
                 partitionId, this.metadataManager, strBuffer, result)) {
             builder.setErrCode(result.getErrCode());
             builder.setErrMsg(result.getErrMsg());
@@ -1222,7 +1310,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                 : consumerNodeInfo.getQryPriorityId();
     }
 
-    /***
+    /**
      * Consumer timeout handler. Update consumer's info if exists consumer timeout.
      */
     public class ConsumerTimeoutListener implements TimeoutListener {
