@@ -51,13 +51,15 @@ import org.apache.inlong.tubemq.server.broker.metadata.MetadataManager;
 import org.apache.inlong.tubemq.server.broker.metadata.TopicMetadata;
 import org.apache.inlong.tubemq.server.broker.msgstore.disk.GetMessageResult;
 import org.apache.inlong.tubemq.server.broker.nodeinfo.ConsumerNodeInfo;
+import org.apache.inlong.tubemq.server.broker.offset.OffsetRecordInfo;
+import org.apache.inlong.tubemq.server.broker.offset.RecordItem;
 import org.apache.inlong.tubemq.server.broker.utils.DataStoreUtils;
 import org.apache.inlong.tubemq.server.broker.utils.TopicPubStoreInfo;
 import org.apache.inlong.tubemq.server.common.TStatusConstants;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-/***
+/**
  * Message storage management. It contains all topics on broker. In charge of store, expire, and flush operation,
  */
 public class MessageStoreManager implements StoreService {
@@ -79,10 +81,17 @@ public class MessageStoreManager implements StoreService {
     // message on memory sink to disk operation scheduler.
     private final ScheduledExecutorService unFlushMemScheduler;
     // max transfer size.
-    private int maxMsgTransferSize;
+    private final int maxMsgTransferSize;
     // the status that is deleting topic.
-    private AtomicBoolean isRemovingTopic = new AtomicBoolean(false);
+    private final AtomicBoolean isRemovingTopic = new AtomicBoolean(false);
 
+    /**
+     * Initial the message-store manager.
+     *
+     * @param tubeBroker      the broker instance
+     * @param tubeConfig      the initial configure
+     * @throws IOException    the exception during processing
+     */
     public MessageStoreManager(final TubeBroker tubeBroker,
                                final BrokerConfig tubeConfig) throws IOException {
         super();
@@ -259,11 +268,11 @@ public class MessageStoreManager implements StoreService {
         }
     }
 
-    /***
+    /**
      * Get message store by topic.
      *
-     * @param topic
-     * @return
+     * @param topic  query topic name
+     * @return       the queried topic's store list
      */
     @Override
     public Collection<MessageStore> getMessageStoresByTopic(final String topic) {
@@ -275,13 +284,13 @@ public class MessageStoreManager implements StoreService {
         return map.values();
     }
 
-    /***
+    /**
      * Get or create message store.
      *
-     * @param topic
-     * @param partition
-     * @return
-     * @throws IOException
+     * @param topic           the topic name
+     * @param partition       the partition id
+     * @return                the message-store instance
+     * @throws IOException    the exception during processing
      */
     @Override
     public MessageStore getOrCreateMessageStore(final String topic,
@@ -337,16 +346,16 @@ public class MessageStoreManager implements StoreService {
         return this.tubeBroker;
     }
 
-    /***
+    /**
      * Get message from store.
      *
-     * @param msgStore
-     * @param topic
-     * @param partitionId
-     * @param msgCount
-     * @param filterCondSet
-     * @return
-     * @throws IOException
+     * @param msgStore        the message-store
+     * @param topic           the topic name
+     * @param partitionId     the partition id
+     * @param msgCount        the message count to read
+     * @param filterCondSet   the filter condition set
+     * @return                the query result
+     * @throws IOException    the exception during processing
      */
     public GetMessageResult getMessages(final MessageStore msgStore,
                                         final String topic,
@@ -366,7 +375,7 @@ public class MessageStoreManager implements StoreService {
             }
             requestOffset = maxOffset - maxIndexReadSize < 0 ? 0L : maxOffset - maxIndexReadSize;
             return msgStore.getMessages(303, requestOffset, partitionId,
-                    consumerNodeInfo, topic, this.maxMsgTransferSize);
+                    consumerNodeInfo, topic, this.maxMsgTransferSize, 0);
         } catch (Throwable e1) {
             return new GetMessageResult(false, TErrCodeConstants.INTERNAL_SERVER_ERROR,
                     requestOffset, 0, "Get message failure, errMsg=" + e1.getMessage());
@@ -385,7 +394,7 @@ public class MessageStoreManager implements StoreService {
         return Collections.unmodifiableMap(this.dataStores);
     }
 
-    /***
+    /**
      * Query topic's publish info.
      *
      * @param topicSet query's topic set
@@ -442,6 +451,50 @@ public class MessageStoreManager implements StoreService {
         return topicPubStoreInfoMap;
     }
 
+    /**
+     * Query topic's publish info.
+     *
+     * @param groupOffsetMap query's topic set
+     *
+     */
+    @Override
+    public void getTopicPublishInfos(Map<String, OffsetRecordInfo> groupOffsetMap) {
+        MessageStore store = null;
+        for (Map.Entry<String, OffsetRecordInfo> entry : groupOffsetMap.entrySet()) {
+            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
+                continue;
+            }
+            Map<String, Map<Integer, RecordItem>> topicOffsetMap =
+                    entry.getValue().getOffsetMap();
+            // Get offset records by topic
+            for (Map.Entry<String, Map<Integer, RecordItem>> entryTopic
+                    : topicOffsetMap.entrySet()) {
+                if (entryTopic == null
+                        || entryTopic.getKey() == null
+                        || entryTopic.getValue() == null) {
+                    continue;
+                }
+                // Get message store instance
+                Map<Integer, MessageStore> storeMap =
+                        dataStores.get(entryTopic.getKey());
+                if (storeMap == null) {
+                    continue;
+                }
+                for (Map.Entry<Integer, RecordItem> entryRcd
+                        : entryTopic.getValue().entrySet()) {
+                    store = storeMap.get(entryRcd.getValue().getStoreId());
+                    if (store == null) {
+                        continue;
+                    }
+                    // Append current max, min offset
+                    entryRcd.getValue().addStoreInfo(store.getIndexMinOffset(),
+                            store.getIndexMaxOffset(), store.getDataMinOffset(),
+                            store.getDataMaxOffset());
+                }
+            }
+        }
+    }
+
     private Set<File> getLogDirSet(final BrokerConfig tubeConfig) throws IOException {
         TopicMetadata topicMetadata = null;
         final Set<String> paths = new HashSet<>();
@@ -471,12 +524,12 @@ public class MessageStoreManager implements StoreService {
         return fileSet;
     }
 
-    /***
+    /**
      * Load stores sequential.
      *
-     * @param tubeConfig
-     * @throws IOException
-     * @throws InterruptedException
+     * @param tubeConfig             the broker's configure
+     * @throws IOException           the exception during processing
+     * @throws InterruptedException  the exception during processing
      */
     private void loadMessageStores(final BrokerConfig tubeConfig)
             throws IOException, InterruptedException {
@@ -574,11 +627,11 @@ public class MessageStoreManager implements StoreService {
                 .append((System.currentTimeMillis() - start) / 1000).append(" secs").toString());
     }
 
-    /***
+    /**
      * Load stores in parallel.
      *
-     * @param tasks
-     * @throws InterruptedException
+     * @param tasks                    the load tasks
+     * @throws InterruptedException    the exception during processing
      */
     private void loadStoresInParallel(List<Callable<MessageStore>> tasks) throws InterruptedException {
         ExecutorService executor =
@@ -615,6 +668,12 @@ public class MessageStoreManager implements StoreService {
         }
     }
 
+    /**
+     * Refresh message-store's dynamic configures
+     *
+     * @param oldTopicConfigMap     the stored topic configure map
+     * @param newTopicConfigMap     the newly topic configure map
+     */
     public void refreshMessageStoresHoldVals(Map<String, TopicMetadata> oldTopicConfigMap,
                                              Map<String, TopicMetadata> newTopicConfigMap) {
         if (((newTopicConfigMap == null) || newTopicConfigMap.isEmpty())
