@@ -26,7 +26,7 @@ import org.apache.inlong.tubemq.corebase.utils.Tuple3;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStore;
 import org.apache.inlong.tubemq.server.common.offsetstorage.OffsetStorageInfo;
 
-/***
+/**
  * Offset manager service interface.
  */
 public interface OffsetService {
@@ -68,6 +68,8 @@ public interface OffsetService {
     Map<String, Map<Integer, Tuple2<Long, Long>>> queryGroupOffset(
             String group, Map<String, Set<Integer>> topicPartMap);
 
+    Map<String, OffsetRecordInfo> getOnlineGroupOffsetInfo();
+
     boolean modifyGroupOffset(Set<String> groups,
                               List<Tuple3<String, Integer, Long>> topicPartOffsets,
                               String modifier);
