@@ -18,6 +18,7 @@
 package org.apache.inlong.tubemq.server.common;
 
 import org.apache.inlong.tubemq.corebase.TBaseConstants;
+import org.apache.inlong.tubemq.server.broker.utils.DataStoreUtils;
 
 public final class TServerConstants {
 
@@ -85,4 +86,16 @@ public final class TServerConstants {
     public static final long CFG_REPORT_DEFAULT_SYNC_DURATION = 2 * 3600 * 1000;
     public static final long CFG_STORE_STATS_MAX_REFRESH_DURATION = 20 * 60 * 1000;
 
+    public static final String OFFSET_HISTORY_NAME = "__offset_history__";
+    public static final String TOKEN_OFFSET_GROUP = "$groupName$";
+    public static final int OFFSET_HISTORY_NUMSTORES = 1;
+    public static final int OFFSET_HISTORY_NUMPARTS = 10;
+    public static final long CFG_DEFAULT_GROUP_OFFSET_SCAN_DUR = 60000L;
+    public static final long CFG_MIN_GROUP_OFFSET_SCAN_DUR = 30000L;
+    public static final long CFG_MAX_GROUP_OFFSET_SCAN_DUR = 480000L;
+
+    public static final long CFG_OFFSET_RESET_MIN_ALARM_CHECK =
+            DataStoreUtils.STORE_INDEX_HEAD_LEN * 100000L;
+    public static final long CFG_OFFSET_RESET_MID_ALARM_CHECK =
+            DataStoreUtils.STORE_INDEX_HEAD_LEN * 1000000L;
 }
