@@ -29,6 +29,7 @@ import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
 import org.apache.inlong.tubemq.server.broker.metadata.MetadataManager;
 import org.apache.inlong.tubemq.server.broker.metadata.TopicMetadata;
+import org.apache.inlong.tubemq.server.common.TServerConstants;
 import org.apache.inlong.tubemq.server.common.fielddef.WebFieldDef;
 import org.apache.inlong.tubemq.server.master.MasterConfig;
 import org.apache.inlong.tubemq.server.master.metamanage.MetaDataManager;
@@ -62,9 +63,21 @@ public class PBParameterUtils {
         Set<String> transTopicList = new HashSet<>();
         if (!reqTopicLst.isEmpty()) {
             for (String topic : reqTopicLst) {
-                if (TStringUtils.isNotBlank(topic)) {
-                    transTopicList.add(topic.trim());
+                if (TStringUtils.isBlank(topic)) {
+                    continue;
                 }
+                topic = topic.trim();
+                // filter system topic OFFSET_HISTORY_NAME
+                if (topic.equals(TServerConstants.OFFSET_HISTORY_NAME)) {
+                    retResult.setCheckResult(false,
+                            TErrCodeConstants.BAD_REQUEST,
+                            strBuffer.append("System Topic ")
+                                    .append(TServerConstants.OFFSET_HISTORY_NAME)
+                                    .append(" does not allow client produce data!").toString());
+                    strBuffer.delete(0, strBuffer.length());
+                    return retResult;
+                }
+                transTopicList.add(topic);
             }
         }
         if (transTopicList.size() > TBaseConstants.META_MAX_BOOKED_TOPIC_COUNT) {
@@ -121,6 +134,15 @@ public class PBParameterUtils {
         return retResult;
     }
 
+    /**
+     * Check the validity of the bootstrap Offset information specified by the consumer.
+     *
+     * @param csmType        the topic list to be checked.
+     * @param reqTopicSet    the subscribed topic set
+     * @param requiredParts  the specified partitionKey-bootstrap offset map
+     * @param strBuffer      the string buffer used to construct the result
+     * @return the check result
+     */
     public static ParamCheckResult checkConsumerOffsetSetInfo(ConsumeType csmType,
                                                               final Set<String> reqTopicSet,
                                                               final String requiredParts,
@@ -175,6 +197,17 @@ public class PBParameterUtils {
         return retResult;
     }
 
+    /**
+     * Check the validity of consumer parameters
+     *  which specify partition boostrap Offset and use server-side balancing.
+     *
+     * @param inConsumerInfo      the consumer information
+     * @param masterConfig        the master configure
+     * @param defMetaDataManager  the cluster meta information
+     * @param brokerRunManager    the broker running information
+     * @param strBuffer           the string buffer used to construct the result
+     * @return the check result
+     */
     public static ParamCheckResult checkConsumerInputInfo(ConsumerInfo inConsumerInfo,
                                                           MasterConfig masterConfig,
                                                           MetaDataManager defMetaDataManager,
@@ -218,7 +251,7 @@ public class PBParameterUtils {
                 brokerRunManager.getSubTopicMaxBrokerCount(inConsumerInfo.getTopicSet());
         int curBClientRate = (int) Math.floor(maxBrokerCount / inConsumerInfo.getSourceCount());
         if (curBClientRate > allowRate) {
-            int minClientCnt = (int) (maxBrokerCount / allowRate);
+            int minClientCnt = maxBrokerCount / allowRate;
             if (maxBrokerCount % allowRate != 0) {
                 minClientCnt += 1;
             }
@@ -387,6 +420,7 @@ public class PBParameterUtils {
     /**
      * Check the existing topic name info
      *
+     * @param isProduce      whether to call on the production side
      * @param topicName      the topic name to be checked.
      * @param partitionId    the partition ID where the topic locates
      * @param metadataManager the metadata manager which contains topic information
@@ -394,28 +428,41 @@ public class PBParameterUtils {
      * @param result         the checked result
      * @return the check result
      */
-    public static boolean getTopicNamePartIdInfo(String topicName, int partitionId,
+    public static boolean getTopicNamePartIdInfo(boolean isProduce,
+                                                 String topicName, int partitionId,
                                                  MetadataManager metadataManager,
                                                  StringBuilder strBuffer,
                                                  ProcessResult result) {
+        // Check and get topic name
         if (!getStringParameter(WebFieldDef.TOPICNAME,
                 topicName, strBuffer, result)) {
             return result.isSuccess();
         }
-        String tmpValue = (String) result.getRetData();
-        TopicMetadata topicMetadata = metadataManager.getTopicMetadata(tmpValue);
+        String tgtTopicName = (String) result.getRetData();
+        // Check if it is an allowed calling relationship
+        if (isProduce) {
+            if (tgtTopicName.equals(TServerConstants.OFFSET_HISTORY_NAME)) {
+                result.setFailResult(TErrCodeConstants.FORBIDDEN,
+                        strBuffer.append(WebFieldDef.TOPICNAME.name)
+                                .append(" ").append(tgtTopicName)
+                                .append(" does not allow producers to send data!").toString());
+                strBuffer.delete(0, strBuffer.length());
+                return result.isSuccess();
+            }
+        }
+        TopicMetadata topicMetadata = metadataManager.getTopicMetadata(tgtTopicName);
         if (topicMetadata == null) {
             result.setFailResult(TErrCodeConstants.FORBIDDEN,
                     strBuffer.append(WebFieldDef.TOPICNAME.name)
-                            .append(" ").append(tmpValue)
+                            .append(" ").append(tgtTopicName)
                             .append(" not existed, please check your configure").toString());
             strBuffer.delete(0, strBuffer.length());
             return result.isSuccess();
         }
-        if (metadataManager.isClosedTopic(tmpValue)) {
+        if (metadataManager.isClosedTopic(tgtTopicName)) {
             result.setFailResult(TErrCodeConstants.FORBIDDEN,
                     strBuffer.append(WebFieldDef.TOPICNAME.name)
-                            .append(" ").append(tmpValue)
+                            .append(" ").append(tgtTopicName)
                             .append(" has been closed").toString());
             strBuffer.delete(0, strBuffer.length());
             return result.isSuccess();
@@ -425,7 +472,7 @@ public class PBParameterUtils {
         if ((realPartition < 0) || (realPartition >= topicMetadata.getNumPartitions())) {
             result.setFailResult(TErrCodeConstants.FORBIDDEN,
                     strBuffer.append(WebFieldDef.PARTITIONID.name)
-                            .append(" ").append(tmpValue).append("-").append(partitionId)
+                            .append(" ").append(tgtTopicName).append("-").append(partitionId)
                             .append(" not existed, please check your configure").toString());
             strBuffer.delete(0, strBuffer.length());
             return result.isSuccess();
