@@ -21,8 +21,6 @@ import com.google.gson.Gson;
 import com.google.gson.reflect.TypeToken;
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
-import java.text.DateFormat;
-import java.text.SimpleDateFormat;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.HashSet;
@@ -36,6 +34,7 @@ import org.apache.inlong.tubemq.corebase.TokenConstants;
 import org.apache.inlong.tubemq.corebase.policies.FlowCtrlItem;
 import org.apache.inlong.tubemq.corebase.policies.FlowCtrlRuleHandler;
 import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
+import org.apache.inlong.tubemq.corebase.utils.DateTimeConvertUtils;
 import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
 import org.apache.inlong.tubemq.corebase.utils.Tuple2;
 import org.apache.inlong.tubemq.server.broker.utils.DataStoreUtils;
@@ -1113,16 +1112,15 @@ public class WebParameterUtils {
             result.setSuccResult(defValue);
             return result.isSuccess();
         }
-        try {
-            DateFormat sdf = new SimpleDateFormat(TBaseConstants.META_TMP_DATE_VALUE);
-            Date date = sdf.parse(paramValue);
-            result.setSuccResult(date);
-        } catch (Throwable e) {
+        Date date = DateTimeConvertUtils.yyyyMMddHHmmss2date(paramValue);
+        if (date == null) {
             result.setFailResult(sBuffer.append("Parameter ").append(fieldDef.name)
                     .append("'s value ").append(paramValue)
                     .append(" parse error, required value format is ")
-                    .append(TBaseConstants.META_TMP_DATE_VALUE).toString());
+                    .append(DateTimeConvertUtils.PAT_YYYYMMDDHHMMSS).toString());
             sBuffer.delete(0, sBuffer.length());
+        } else {
+            result.setSuccResult(date);
         }
         return result.isSuccess();
     }
@@ -1205,11 +1203,15 @@ public class WebParameterUtils {
         // check value's pattern
         if (fieldDef.regexCheck) {
             if (!paramVal.matches(fieldDef.regexDef.getPattern())) {
-                result.setFailResult(sBuffer.append("illegal value for ")
-                        .append(fieldDef.name).append(", value ")
-                        .append(fieldDef.regexDef.getErrMsgTemp()).toString());
-                sBuffer.delete(0, sBuffer.length());
-                return false;
+                if ((fieldDef != WebFieldDef.TOPICNAME
+                        && fieldDef != WebFieldDef.COMPSTOPICNAME)
+                        || !paramVal.equals(TServerConstants.OFFSET_HISTORY_NAME)) {
+                    result.setFailResult(sBuffer.append("illegal value for ")
+                            .append(fieldDef.name).append(", value ")
+                            .append(fieldDef.regexDef.getErrMsgTemp()).toString());
+                    sBuffer.delete(0, sBuffer.length());
+                    return false;
+                }
             }
         }
         result.setSuccResult(paramVal);
@@ -1436,68 +1438,6 @@ public class WebParameterUtils {
         return batchOpGroupNames;
     }
 
-    /**
-     * check and get batched topic names
-     *
-     * @param inputTopicName the topic name string value
-     * @param checkEmpty     whether check data emtpy
-     * @param checkRange     whether check topic in range
-     * @param checkedTopicList topics current configured
-     * @param sb             the string process space
-     * @return the batched topic names
-     */
-    public static Set<String> getBatchTopicNames(String inputTopicName,
-                                                 boolean checkEmpty,
-                                                 boolean checkRange,
-                                                 Set<String> checkedTopicList,
-                                                 StringBuilder sb) throws Exception {
-        Set<String> batchOpTopicNames = new HashSet<>();
-        if (TStringUtils.isNotBlank(inputTopicName)) {
-            inputTopicName = escDoubleQuotes(inputTopicName.trim());
-        }
-        if (TStringUtils.isBlank(inputTopicName)) {
-            if (checkEmpty) {
-                throw new Exception("Illegal value: required topicName parameter");
-            }
-            return batchOpTopicNames;
-        }
-        String[] strTopicNames = inputTopicName.split(TokenConstants.ARRAY_SEP);
-        if (strTopicNames.length > TServerConstants.CFG_BATCH_RECORD_OPERATE_MAX_COUNT) {
-            throw new Exception(sb.append("Illegal value: topicName's batch count over max count ")
-                    .append(TServerConstants.CFG_BATCH_RECORD_OPERATE_MAX_COUNT).toString());
-        }
-        for (int i = 0; i < strTopicNames.length; i++) {
-            if (TStringUtils.isBlank(strTopicNames[i])) {
-                continue;
-            }
-            String topicName = strTopicNames[i].trim();
-            if (topicName.length() > TBaseConstants.META_MAX_TOPICNAME_LENGTH) {
-                throw new Exception(sb.append("Illegal value: the max length of ")
-                        .append(topicName).append(" in topicName parameter over ")
-                        .append(TBaseConstants.META_MAX_TOPICNAME_LENGTH)
-                        .append(" characters").toString());
-            }
-            if (!topicName.matches(TBaseConstants.META_TMP_STRING_VALUE)) {
-                throw new Exception(sb.append("Illegal value: the value of ")
-                    .append(topicName).append(" in topicName parameter must begin with a letter,")
-                    .append(" can only contain characters,numbers,and underscores").toString());
-            }
-            if (checkRange) {
-                if (!checkedTopicList.contains(topicName)) {
-                    throw new Exception(sb.append("Illegal value: topic(").append(topicName)
-                            .append(") not configure in master's topic configure, please configure first!").toString());
-                }
-            }
-            batchOpTopicNames.add(topicName);
-        }
-        if (batchOpTopicNames.isEmpty()) {
-            if (checkEmpty) {
-                throw new Exception("Illegal value: Null value of topicName parameter");
-            }
-        }
-        return batchOpTopicNames;
-    }
-
     /**
      * check and get batched broker ips
      *
@@ -1645,44 +1585,13 @@ public class WebParameterUtils {
         return new Tuple2<>(isAcceptPublish, isAcceptSubscribe);
     }
 
-    /**
-     * translate Date value from Date to yyyyMMddHHmmss format string
-     *
-     * @param date date
-     * @return the yyyyMMddHHmmss format string
-     */
-    public static String date2yyyyMMddHHmmss(Date date) {
-        SimpleDateFormat sdf =
-                new SimpleDateFormat(TBaseConstants.META_TMP_DATE_VALUE);
-        return sdf.format(date);
-    }
-
-    /**
-     * translate yyyyMMddHHmmss format string to Date value
-     *
-     * @param dateStr date string, format yyyyMMddHHmmss
-     * @return the Date value of string
-     */
-    public static Date yyyyMMddHHmmss2date(String dateStr) {
-        if (dateStr == null) {
-            return null;
-        }
-        SimpleDateFormat sdf =
-                new SimpleDateFormat(TBaseConstants.META_TMP_DATE_VALUE);
-        try {
-            return sdf.parse(dateStr);
-        } catch (Throwable e) {
-            return null;
-        }
-    }
-
     /**
      * check parameter is required
      *
      * @param paramName   the parameter name
      * @param paramValue  the parameter value
-     * @param required
-     * @return the yyyyMMddHHmmss format string
+     * @param required    Whether the parameter is required
+     * @return the parameter value without quotes
      */
     public static String checkParamCommonRequires(String paramName, String paramValue,
                                                   boolean required) throws Exception {
