@@ -20,8 +20,7 @@ package org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.mapper;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
-import org.apache.inlong.tubemq.server.common.utils.ProcessResult;
+import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.TopicDeployEntity;
 
 public interface TopicDeployMapper extends AbstractMapper {
