@@ -25,8 +25,8 @@ import com.sleepycat.persist.StoreConfig;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.inlong.tubemq.corebase.TBaseConstants;
+import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.server.common.exception.LoadMetaException;
-import org.apache.inlong.tubemq.server.common.utils.ProcessResult;
 import org.apache.inlong.tubemq.server.master.bdbstore.bdbentitys.BdbClusterSettingEntity;
 import org.apache.inlong.tubemq.server.master.metamanage.DataOpErrCode;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.TStoreConstants;
@@ -136,7 +136,7 @@ public class BdbClusterConfigMapperImpl implements ClusterConfigMapper {
         }
         if (putClusterConfig2Bdb(memEntity, result)) {
             metaDataCache.put(memEntity.getRecordKey(), memEntity);
-            result.setRetData(curEntity);
+            result.setSuccResult(curEntity);
         }
         return result.isSuccess();
     }
