@@ -27,12 +27,13 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.commons.lang.builder.ToStringBuilder;
 import org.apache.inlong.tubemq.corebase.TBaseConstants;
+import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.corebase.utils.Tuple2;
 import org.apache.inlong.tubemq.server.common.statusdef.ManageStatus;
-import org.apache.inlong.tubemq.server.common.utils.ProcessResult;
 import org.apache.inlong.tubemq.server.master.metamanage.MetaDataManager;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.BaseEntity;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.BrokerConfEntity;
+import org.apache.inlong.tubemq.server.master.metrics.MasterMetricsHolder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -74,6 +75,7 @@ public class BrokerAbnHolder {
                 if (brokerForbiddenMap.get(brokerId) == null) {
                     brokerAbnInfo = brokerAbnormalMap.remove(brokerId);
                     if (brokerAbnInfo != null) {
+                        MasterMetricsHolder.decBrokerAbnormalCnt();
                         logger.warn(sBuffer.append("[Broker AutoForbidden] broker ")
                                 .append(brokerId).append(" return to normal!").toString());
                         sBuffer.delete(0, sBuffer.length());
@@ -98,6 +100,7 @@ public class BrokerAbnHolder {
         if (brokerAbnInfo == null) {
             if (brokerAbnormalMap.putIfAbsent(brokerId,
                 new BrokerAbnInfo(brokerId, reportReadStatus, reportWriteStatus)) == null) {
+                MasterMetricsHolder.incBrokerAbnormalCnt();
                 logger.warn(sBuffer.append("[Broker AutoForbidden] broker report abnormal, ")
                         .append(brokerId).append("'s reportReadStatus=")
                         .append(reportReadStatus).append(", reportWriteStatus=")
@@ -116,6 +119,7 @@ public class BrokerAbnHolder {
                 if (updateCurManageStatus(brokerId, reqMngStatus, sBuffer)) {
                     if (brokerForbiddenMap.putIfAbsent(brokerId, tmpBrokerFbdInfo) == null) {
                         brokerForbiddenCount.incrementAndGet();
+                        MasterMetricsHolder.incBrokerForbiddenCnt();
                         logger.warn(sBuffer
                                 .append("[Broker AutoForbidden] master add missing forbidden broker, ")
                                 .append(brokerId).append("'s manage status to ")
@@ -133,6 +137,7 @@ public class BrokerAbnHolder {
                         brokerForbiddenCount.decrementAndGet();
                         return;
                     }
+                    MasterMetricsHolder.incBrokerForbiddenCnt();
                     logger.warn(sBuffer
                             .append("[Broker AutoForbidden] master auto forbidden broker, ")
                             .append(brokerId).append("'s manage status to ")
@@ -172,10 +177,14 @@ public class BrokerAbnHolder {
      * @param brokerId the deleted broker id
      */
     public void removeBroker(Integer brokerId) {
-        brokerAbnormalMap.remove(brokerId);
+        BrokerAbnInfo abnInfo = brokerAbnormalMap.remove(brokerId);
+        if (abnInfo != null) {
+            MasterMetricsHolder.decBrokerAbnormalCnt();
+        }
         BrokerFbdInfo brokerFbdInfo = brokerForbiddenMap.remove(brokerId);
         if (brokerFbdInfo != null) {
             this.brokerForbiddenCount.decrementAndGet();
+            MasterMetricsHolder.decBrokerForbiddenCnt();
         }
     }
 
@@ -258,8 +267,12 @@ public class BrokerAbnHolder {
             BrokerFbdInfo fbdInfo = this.brokerForbiddenMap.remove(brokerId);
             if (fbdInfo != null) {
                 brokerFbdInfos.add(fbdInfo);
-                this.brokerAbnormalMap.remove(brokerId);
+                BrokerAbnInfo abnInfo = this.brokerAbnormalMap.remove(brokerId);
+                if (abnInfo != null) {
+                    MasterMetricsHolder.decBrokerAbnormalCnt();
+                }
                 this.brokerForbiddenCount.decrementAndGet();
+                MasterMetricsHolder.decBrokerForbiddenCnt();
             }
         }
         if (!brokerFbdInfos.isEmpty()) {
