@@ -31,6 +31,7 @@ import org.apache.inlong.tubemq.corebase.cluster.Partition;
 import org.apache.inlong.tubemq.corebase.cluster.TopicInfo;
 import org.apache.inlong.tubemq.corebase.protobuf.generated.ClientMaster.HeartResponseM2B;
 import org.apache.inlong.tubemq.corebase.protobuf.generated.ClientMaster.RegisterResponseM2B;
+import org.apache.inlong.tubemq.corebase.rv.ProcessResult;
 import org.apache.inlong.tubemq.corebase.utils.Tuple2;
 import org.apache.inlong.tubemq.corebase.utils.Tuple3;
 import org.apache.inlong.tubemq.corebase.utils.Tuple4;
@@ -38,13 +39,13 @@ import org.apache.inlong.tubemq.server.common.heartbeat.HeartbeatManager;
 import org.apache.inlong.tubemq.server.common.heartbeat.TimeoutInfo;
 import org.apache.inlong.tubemq.server.common.heartbeat.TimeoutListener;
 import org.apache.inlong.tubemq.server.common.statusdef.ManageStatus;
-import org.apache.inlong.tubemq.server.common.utils.ProcessResult;
 import org.apache.inlong.tubemq.server.common.utils.SerialIdUtils;
 import org.apache.inlong.tubemq.server.master.MasterConfig;
 import org.apache.inlong.tubemq.server.master.TMaster;
 import org.apache.inlong.tubemq.server.master.metamanage.MetaDataManager;
 import org.apache.inlong.tubemq.server.master.metamanage.keepalive.AliveObserver;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.BrokerConfEntity;
+import org.apache.inlong.tubemq.server.master.metrics.MasterMetricsHolder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -86,8 +87,7 @@ public class DefBrokerRunManager implements BrokerRunManager, AliveObserver {
         this.heartbeatManager = tMaster.getHeartbeatManager();
         MasterConfig masterConfig = tMaster.getMasterConfig();
         this.brokerAbnHolder =
-                new BrokerAbnHolder(masterConfig.getMaxAutoForbiddenCnt(),
-                        this.metaDataManager);
+                new BrokerAbnHolder(masterConfig.getMaxAutoForbiddenCnt(), this.metaDataManager);
         heartbeatManager.regBrokerCheckBusiness(masterConfig.getBrokerHeartbeatTimeoutMs(),
                 new TimeoutListener() {
                     @Override
@@ -145,9 +145,12 @@ public class DefBrokerRunManager implements BrokerRunManager, AliveObserver {
                 || brokerTLSReg == null
                 || !brokerReg.equals(entity.getSimpleBrokerInfo())
                 || !brokerTLSReg.equals(entity.getSimpleTLSBrokerInfo())) {
-            if (brokerReg != null
-                    && !brokerReg.equals(entity.getSimpleBrokerInfo())) {
-                this.brokersMap.put(entity.getBrokerId(), entity.getSimpleBrokerInfo());
+            if (brokerReg == null) {
+                MasterMetricsHolder.incBrokerConfigCnt();
+            } else {
+                if (!brokerReg.equals(entity.getSimpleBrokerInfo())) {
+                    this.brokersMap.put(entity.getBrokerId(), entity.getSimpleBrokerInfo());
+                }
             }
             if (brokerTLSReg != null
                     && !brokerTLSReg.equals(entity.getSimpleTLSBrokerInfo())) {
@@ -241,6 +244,7 @@ public class DefBrokerRunManager implements BrokerRunManager, AliveObserver {
                             brokerInfo.getBrokerId(), tmpRunStatusInfo);
             if (runStatusInfo == null) {
                 brokerTotalCount.incrementAndGet();
+                MasterMetricsHolder.incBrokerOnlineCnt();
                 runStatusInfo = tmpRunStatusInfo;
             }
         } else {
@@ -285,7 +289,7 @@ public class DefBrokerRunManager implements BrokerRunManager, AliveObserver {
                     removedTopics, sBuffer, result);
             logger.info(sBuffer.append("[Broker Report] receive broker removed topics = ")
                     .append(removedTopics.toString()).append(", removed result is ")
-                    .append(result.getErrInfo()).toString());
+                    .append(result.getErrMsg()).toString());
             sBuffer.delete(0, sBuffer.length());
         }
         brokerAbnHolder.updateBrokerReportStatus(brokerId, rptReadStatus, rptWriteStatus);
@@ -471,6 +475,7 @@ public class DefBrokerRunManager implements BrokerRunManager, AliveObserver {
         if (runStatusInfo == null) {
             return false;
         }
+        MasterMetricsHolder.decBrokerOnlineCnt(isTimeout);
         brokerTotalCount.decrementAndGet();
         brokerAbnHolder.removeBroker(brokerId);
         brokerPubSubInfo.rmvBrokerAllPushedInfo(brokerId);
